@@ -420,8 +420,8 @@ int quicktime_read_mp4_descr_length(quicktime_t * file);
    other parameters can be set by the encoder */
 
 LQT_EXTERN quicktime_esds_t * quicktime_set_esds(quicktime_trak_t * trak,
-                                      uint8_t * decoderConfig,
-                                      int decoderConfigLen);
+                                                 const uint8_t * decoderConfig,
+                                                 int decoderConfigLen);
 
 /* fiel.c */
 
@@ -566,6 +566,11 @@ LQT_EXTERN void lqt_logs(quicktime_t * file, lqt_log_level_t level,
 /* For dumping strings */
 void lqt_dump(const char * format, ...)  __attribute__ ((format (printf, 1, 2)));
 
+/* lqt_codecinfo.c */
+
+lqt_codec_info_t * lqt_codec_info_copy_single(const lqt_codec_info_t * info);
+void lqt_codec_info_destroy_single(lqt_codec_info_t * info);
+
 /* matrix.c */
 
 void quicktime_matrix_init(quicktime_matrix_t *matrix);
@@ -917,6 +922,11 @@ void quicktime_write_stsd(quicktime_t *file, quicktime_minf_t *minf, quicktime_s
 void quicktime_finalize_stsd(quicktime_t * file, quicktime_trak_t * trak, quicktime_stsd_t * stsd);
 
 
+void quicktime_stsd_set_video_codec(quicktime_stsd_t *stsd, 
+                                    char * compression);
+
+void quicktime_stsd_set_audio_codec(quicktime_stsd_t *stsd, 
+                                    char * compression);
 
 void quicktime_stsd_init_video(quicktime_t *file, 
                                quicktime_stsd_t *stsd, 
@@ -1180,13 +1190,10 @@ int64_t quicktime_sample_range_size(quicktime_trak_t *trak,
 int64_t quicktime_sample_to_offset(quicktime_t *file, quicktime_trak_t *trak, long sample);
 
 LQT_EXTERN void quicktime_write_chunk_header(quicktime_t *file, 
-                                             quicktime_trak_t *trak, 
-                                             quicktime_atom_t *chunk);
+                                             quicktime_trak_t *trak);
+
 LQT_EXTERN void quicktime_write_chunk_footer(quicktime_t *file, 
-                                             quicktime_trak_t *trak,
-                                             int current_chunk,
-                                             quicktime_atom_t *chunk, 
-                                             int samples);
+                                             quicktime_trak_t *trak);
 
 int quicktime_trak_duration(quicktime_trak_t *trak, 
                             int64_t *duration, 
@@ -1217,7 +1224,8 @@ void lqt_flush_timecode(quicktime_t * file, int track, int64_t time,
 void quicktime_tmcd_dump(quicktime_tmcd_t *tmcd);
 void quicktime_tmcd_init(quicktime_tmcd_t *tmcd);
 void quicktime_tmcd_delete(quicktime_tmcd_t *tmcd);
-void quicktime_read_tmcd(quicktime_t *file, quicktime_tmcd_t *tmcd, quicktime_atom_t *parent_atom);
+void quicktime_read_tmcd(quicktime_t *file, quicktime_tmcd_t *tmcd,
+                         quicktime_atom_t *parent_atom);
 void quicktime_write_tmcd(quicktime_t *file, quicktime_tmcd_t *tmcd);
 
 
@@ -1366,13 +1374,13 @@ quicktime_trak_t* quicktime_add_track(quicktime_t *);
 int quicktime_get_timescale(double frame_rate);
 
 int quicktime_init_audio_map(quicktime_t * file,
-                             quicktime_audio_map_t *atrack, quicktime_trak_t *trak,
+                             quicktime_audio_map_t *atrack,
                              int encode, lqt_codec_info_t * info);
 
 int quicktime_delete_audio_map(quicktime_audio_map_t *atrack);
 
 
-int quicktime_init_video_map(quicktime_video_map_t *vtrack, quicktime_trak_t *trak,
+int quicktime_init_video_map(quicktime_video_map_t *vtrack,
                              int encode, lqt_codec_info_t * info);
 
 int quicktime_delete_video_map(quicktime_video_map_t *vtrack);
@@ -1381,7 +1389,6 @@ int quicktime_delete_video_map(quicktime_video_map_t *vtrack);
 void quicktime_init_maps(quicktime_t * file);
 void lqt_update_frame_position(quicktime_video_map_t * track);
 
-LQT_EXTERN void lqt_start_audio_vbr_chunk(quicktime_t * file, int track);
 LQT_EXTERN void lqt_init_vbr_audio(quicktime_t * file, int track);
 
 LQT_EXTERN int lqt_chunk_of_sample_vbr(int64_t *chunk_sample, 
@@ -1389,11 +1396,30 @@ LQT_EXTERN int lqt_chunk_of_sample_vbr(int64_t *chunk_sample,
                                        quicktime_trak_t *trak, 
                                        int64_t sample);
 
+LQT_EXTERN void lqt_set_audio_bitrate(quicktime_t * file, int track, int bitrate);
+
+
+int lqt_add_audio_track_internal(quicktime_t *file,
+                                 int channels, long sample_rate, int bits,
+                                 lqt_codec_info_t * codec_info,
+                                 const lqt_compression_info_t * ci);
+
+int lqt_add_video_track_internal(quicktime_t *file,
+                                 int frame_w, int frame_h,
+                                 int frame_duration, int timescale,
+                                 lqt_codec_info_t * info,
+                                 const lqt_compression_info_t * ci);
+
+
+int lqt_is_keyframe(quicktime_t *file, int track, int frame);
+
+
 /* Read all the information about the file. */
 /* Requires a MOOV atom be present in the file. */
 /* If no MOOV atom exists return 1 else return 0. */
 int quicktime_read_info(quicktime_t *file);
 
+void lqt_start_encoding(quicktime_t *file);
 
 /*
  *  Set the default codec parameters from the registry
@@ -1427,8 +1453,7 @@ int quicktime_init_vcodec(quicktime_video_map_t *vtrack, int encode,
 int quicktime_init_acodec(quicktime_audio_map_t *atrack, int encode,
                           lqt_codec_info_t * info);
 
-int quicktime_delete_vcodec(quicktime_video_map_t *vtrack);
-int quicktime_delete_acodec(quicktime_audio_map_t *vtrack);
+int quicktime_delete_codec(quicktime_codec_t *codec);
 int quicktime_codecs_flush(quicktime_t *file);
 
 LQT_EXTERN void lqt_write_frame_header(quicktime_t * file, int track,
@@ -1442,6 +1467,11 @@ void lqt_video_build_timestamp_tables(quicktime_t * file, int track);
 LQT_EXTERN void lqt_video_append_timestamp(quicktime_t * file, int track,
                                            int64_t time, int duration);
 
+quicktime_codec_t * quicktime_load_codec(lqt_codec_info_t * info,
+                                         quicktime_audio_map_t * amap,
+                                         quicktime_video_map_t * vmap);
+
+
 /* workarounds.c */
 
 int64_t quicktime_add3(int64_t a, int64_t b, int64_t c);
