@@ -32,6 +32,7 @@
 #include <quicktime/lqt.h>
 
 #include <quicktime/qtprivate.h>
+#include <quicktime/compression.h>
 
 #ifdef HAVE_GCC_VISIBILITY
 #define LQT_EXTERN __attribute__ ((visibility("default"))) 
@@ -53,8 +54,9 @@
  *   which should be returned by get_codec()
  */
 
-typedef void (* lqt_init_video_codec_func_t)(quicktime_video_map_t *);
-typedef void (* lqt_init_audio_codec_func_t)(quicktime_audio_map_t *);
+typedef void (* lqt_init_codec_func_t)(quicktime_codec_t * codec,
+                                       quicktime_audio_map_t *,
+                                       quicktime_video_map_t *);
 
 typedef struct
   {
@@ -89,6 +91,12 @@ typedef struct
   
   } lqt_parameter_info_static_t;
 
+typedef struct
+  {
+  int width;
+  int height;
+  } lqt_image_size_static_t;
+
 /*
  *   This holds the parts of the codec_info structure,
  *   which can be defined statically in the codec source
@@ -121,6 +129,10 @@ typedef struct
 
   int * encoding_colormodels;
   
+  lqt_image_size_static_t * image_sizes;
+  
+  lqt_compression_id_t compression_id;
+  
   } lqt_codec_info_static_t;
 
 /*
@@ -137,8 +149,7 @@ int get_codec_api_version(void) { return LQT_CODEC_API_VERSION; }
 /* Declarations for the codec functions */
 LQT_EXTERN int get_num_codecs();
 LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index);
-LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index);
-LQT_EXTERN lqt_init_video_codec_func_t get_video_codec(int index);
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index);
 #endif
 
 /*
