@@ -197,6 +197,7 @@ static lqt_codec_info_static_t codec_info_ulaw =
     .encoding_parameters = (lqt_parameter_info_static_t*)0,
     .decoding_parameters = (lqt_parameter_info_static_t*)0,
     .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
+    .compression_id = LQT_COMPRESSION_ULAW,
   };
 
 static lqt_codec_info_static_t codec_info_alaw =
@@ -211,6 +212,7 @@ static lqt_codec_info_static_t codec_info_alaw =
     .encoding_parameters = (lqt_parameter_info_static_t*)0,
     .decoding_parameters = (lqt_parameter_info_static_t*)0,
     .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
+    .compression_id = LQT_COMPRESSION_ALAW,
   };
 
 
@@ -288,7 +290,7 @@ LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
   return (lqt_codec_info_static_t*)0;
   }
      
-LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index)
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index)
   {
   switch(index)
     {
@@ -326,5 +328,5 @@ LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index)
       return quicktime_init_codec_lpcm;
       break;
     }
-  return (lqt_init_audio_codec_func_t)0;
+  return (lqt_init_codec_func_t)0;
   }
