@@ -60,7 +60,7 @@ LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
  *   Return the actual codec constructor
  */
 
-LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index)
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index)
   {
   return quicktime_init_codec_faad2;
   }
