@@ -170,6 +170,21 @@ int ffmpeg_num_video_codecs = -1;
     PARAM_FLAG_BITEXACT, \
     PARAM_THREAD_COUNT
 
+#define ENCODE_PARAM_IMX \
+  { \
+    .name = "imx_bitrate",                        \
+    .real_name = TRS("Bitrate (Mbps)"),                \
+    .type = LQT_PARAMETER_STRINGLIST, \
+    .val_default = { .val_string =  "50" },             \
+    .stringlist_options = (char *[]){ "30", "40", "50", \
+                                      (char *)0 }       \
+  }, \
+  {  \
+    .name = "imx_strip_vbi",         \
+    .real_name = TRS("Strip VBI"),   \
+    .type = LQT_PARAMETER_INT,       \
+    .val_default = { .val_int = 1 }  \
+  }
 
 #define DECODE_PARAM_AUDIO
 
@@ -264,6 +279,12 @@ static lqt_parameter_info_static_t encode_parameters_ffv1[] = {
   { /* End of parameters */ }
 };
 
+static lqt_parameter_info_static_t encode_parameters_imx[] = {
+  ENCODE_PARAM_IMX,
+  { /* End of parameters */ }
+};
+
+
 static lqt_parameter_info_static_t encode_parameters_audio[] = {
   ENCODE_PARAM_AUDIO,
   { /* End of parameters */ }
@@ -278,26 +299,76 @@ static lqt_parameter_info_static_t decode_parameters_audio[] = {
   { /* End of parameters */ }
 };
 
-struct CODECIDMAP {
-	int id;
-	int index;
-	AVCodec *encoder;
-	AVCodec *decoder;
-        lqt_parameter_info_static_t * encode_parameters;
-        lqt_parameter_info_static_t * decode_parameters;
-	char *short_name;
-	char *name;
-	char *fourccs[MAX_FOURCCS];
-        int   wav_ids[MAX_WAV_IDS];
-        int compatibility_flags;
-/*
- *  We explicitely allow, if encoding is allowed.
- *  This prevents the spreading of broken files
- */
-        int   do_encode;
-        int   * encoding_colormodels;
+struct CODECIDMAP
+  {
+  int id;
+  int index;
+  AVCodec *encoder;
+  AVCodec *decoder;
+  lqt_parameter_info_static_t * encode_parameters;
+  lqt_parameter_info_static_t * decode_parameters;
+  lqt_image_size_static_t     * image_sizes;
+  
+  char *short_name;
+  char *name;
+  char *fourccs[MAX_FOURCCS];
+  int   wav_ids[MAX_WAV_IDS];
+  int compatibility_flags;
+  /*
+   *  We explicitely allow, if encoding is allowed.
+   *  This prevents the spreading of broken files
+   */
+  int   do_encode;
+  int   * encoding_colormodels;
+  
+  lqt_compression_id_t compression_id;
   };
 
+/* Image sizes */
+
+static lqt_image_size_static_t image_sizes_imx[] =
+  {
+    { 720, 576 }, // PAL without VBI
+    { 720, 608 }, // PAL with VBi
+    { 720, 486 }, // NTSC without VBI
+    { 720, 512 }, // NTSC with VBi
+    { /* End */ },
+  };
+
+#if 0 // TODO: Simpify DV encoders
+static lqt_image_size_static_t image_sizes_dv[] =
+  {
+    { 720, 575 }, // PAL
+    { 720, 480 }, // NTSC
+    { /* End */ },
+  };
+#endif
+
+static lqt_image_size_static_t image_sizes_h263[] =
+  {
+    {  128, 96 }, // sub-QCIF
+    {  176, 144 }, // QCIF
+    {  352, 288 }, // CIF
+    {  704, 576 }, // 4CIF
+    { 1408, 1152 }, // 16CIF
+    { /* End */ },
+  };
+
+static lqt_image_size_static_t image_sizes_dnxhd[] =
+  {
+    { 1920, 1080 },
+    { 1280,  720 },
+    { /* End */ },
+  };
+
+static lqt_image_size_static_t image_sizes_dv[] =
+  {
+    {  720, 576 },
+    {  720, 480 },
+    { /* End */ },
+  };
+
+
 /* Video; tables from mplayers config... */
 
 struct CODECIDMAP codecidmap_v[] =
@@ -324,11 +395,12 @@ struct CODECIDMAP codecidmap_v[] =
       .name = TRS("FFMPEG MPEG-4"),
       .fourccs = { "mp4v", "divx", "DIV1", "div1", "MP4S", "mp4s",
                    "M4S2", "m4s2", "xvid", "XVID", "XviD", "DX50",
-                   "dx50", "DIVX", "MP4V", "3IV2", (char *)0 },
+                   "dx50", "DIVX", "MP4V", "3IV2", "FMP4", (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
       .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_MP4 |
                              LQT_FILE_3GP  | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
-      .do_encode = 1
+      .do_encode = 1,
+      .compression_id = LQT_COMPRESSION_MPEG4_ASP,
     },
     {
       .id = CODEC_ID_MSMPEG4V1,
@@ -415,6 +487,7 @@ struct CODECIDMAP codecidmap_v[] =
       .decoder = NULL,
       .encode_parameters = encode_parameters_h263,
       .decode_parameters = decode_parameters_video,
+      .image_sizes = image_sizes_h263,
       .short_name = "h263",
       .name = TRS("FFMPEG H263"),
       .fourccs = { "H263", "h263", "s263", (char *)0 },
@@ -605,6 +678,7 @@ struct CODECIDMAP codecidmap_v[] =
       .wav_ids = { LQT_WAV_ID_NONE },
       .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
       .do_encode = 1,
+      .encoding_colormodels = (int[]){ BC_RGB888, BC_RGBA8888, LQT_COLORMODEL_NONE },
     },
     {
       .id = CODEC_ID_MSRLE,
@@ -623,12 +697,14 @@ struct CODECIDMAP codecidmap_v[] =
       .decoder = NULL,
       .encode_parameters = encode_parameters_dvvideo,
       .decode_parameters = decode_parameters_video,
-      .short_name = "dv_ntsc",
-      .name = TRS("FFMPEG DV (NTSC)"),
-      .fourccs = { "dvc ", (char *)0 },
+      .short_name = "dv",
+      .name = TRS("FFMPEG DV"),
+      .fourccs = { "dvc ", "dvcp", "dvpp", "dvsd", "dv25", (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
-      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
+      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
       .do_encode = 1,
+      .compression_id = LQT_COMPRESSION_DV, // Also writes all other DV flavours
+      .image_sizes = image_sizes_dv,
     },
     {
       .id = CODEC_ID_DVVIDEO,
@@ -637,12 +713,14 @@ struct CODECIDMAP codecidmap_v[] =
       .decoder = NULL,
       .encode_parameters = encode_parameters_dvvideo,
       .decode_parameters = decode_parameters_video,
-      .short_name = "dv_pal",
-      .name = TRS("FFMPEG DV (PAL)"),
-      .fourccs = { "dvcp", "dvpp", (char *)0 },
+      .short_name = "dvcpro",
+      .name = TRS("FFMPEG DVCPRO"),
+      .fourccs = { "dvpp", (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
-      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
-      .do_encode = 1
+      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
+      .do_encode = 1,
+      .compression_id = LQT_COMPRESSION_DV, // Also writes all other DV flavours
+      .image_sizes = image_sizes_dv,
     },
     {
       .id = CODEC_ID_DVVIDEO,
@@ -651,40 +729,13 @@ struct CODECIDMAP codecidmap_v[] =
       .decoder = NULL,
       .encode_parameters = encode_parameters_dvvideo,
       .decode_parameters = decode_parameters_video,
-      .short_name = "dv_avi",
-      .name = TRS("FFMPEG DV (AVI version)"),
-      .fourccs = { "dvsd", (char *)0 },
+      .short_name = "dv50",
+      .name = TRS("FFMPEG DVCPRO50"),
+      .fourccs = { "dv5p", "dv5n", "dv50", (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
-      .compatibility_flags = LQT_FILE_AVI | LQT_FILE_AVI_ODML,
-      .do_encode = 1
-    },
-    {
-      .id = CODEC_ID_DVVIDEO,
-      .index = -1,
-      .encoder = NULL,
-      .decoder = NULL,
-      .encode_parameters = encode_parameters_dvvideo,
-      .decode_parameters = decode_parameters_video,
-      .short_name = "dv50_pal",
-      .name = TRS("FFMPEG DVCPRO50 (PAL)"),
-      .fourccs = { "dv5p", (char *)0 },
-      .wav_ids = { LQT_WAV_ID_NONE },
-      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
-      .do_encode = 1
-    },
-    {
-      .id = CODEC_ID_DVVIDEO,
-      .index = -1,
-      .encoder = NULL,
-      .decoder = NULL,
-      .encode_parameters = encode_parameters_dvvideo,
-      .decode_parameters = decode_parameters_video,
-      .short_name = "dv50_ntsc",
-      .name = TRS("FFMPEG DVCPRO50 (NTSC)"),
-	    .fourccs = { "dv5n", (char *)0 },
-      .wav_ids = { LQT_WAV_ID_NONE },
-      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
-      .do_encode = 1
+      .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
+      .do_encode = 1,
+      .image_sizes = image_sizes_dv,
     },
     /* DVCPRO HD (decoding only for now) */
     {
@@ -701,11 +752,12 @@ struct CODECIDMAP codecidmap_v[] =
                    "dvh5", // DVCPRO HD 50i produced by FCP
                    "dvh6", // DVCPRO HD 60i produced by FCP
                    "dvh3", // DVCPRO HD 30p produced by FCP
+                   "dvh1", // 
                    "AVd1", // AVID DV100
                    (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
       .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
-      .do_encode = 1
+      // .do_encode = 1
     },
     {
       .id = CODEC_ID_FFVHUFF,
@@ -742,6 +794,7 @@ struct CODECIDMAP codecidmap_v[] =
       .encoder = NULL,
       .decoder = NULL,
       .decode_parameters = decode_parameters_video,
+      .image_sizes = image_sizes_dnxhd,
       .short_name = "dnxhd",
       .name = TRS("FFMPEG dnxhd"),
             .fourccs = { "AVdn", (char *)0 },
@@ -756,12 +809,15 @@ struct CODECIDMAP codecidmap_v[] =
       .encoder = NULL,
       .decoder = NULL,
       .decode_parameters = decode_parameters_video,
+      .encode_parameters = encode_parameters_imx,
+      .image_sizes = image_sizes_imx,
       .short_name = "imx",
       .name = TRS("FFMPEG IMX"),
       .fourccs = { "mx3p", "mx3n", "mx4p", "mx4n", "mx5p", "mx5n", (char *)0 },
       .wav_ids = { LQT_WAV_ID_NONE },
       .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT,
-      .do_encode = 0
+      .do_encode = 1,
+      .compression_id = LQT_COMPRESSION_D10
     },
 };
 
@@ -794,6 +850,7 @@ struct CODECIDMAP codecidmap_a[] =
       .wav_ids = { 0x55, LQT_WAV_ID_NONE },
       .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_AVI | LQT_FILE_AVI_ODML,
       .do_encode = 1,
+      .compression_id = LQT_COMPRESSION_MP2,
     },
     {
       .id = CODEC_ID_AC3,
@@ -804,10 +861,11 @@ struct CODECIDMAP codecidmap_a[] =
       .decode_parameters = decode_parameters_audio,
       .short_name = "ac3",
       .name = TRS("FFMPEG AC3 Audio"),
-      .fourccs = { ".ac3", ".AC3", (char *)0 },
+      .fourccs = { "ac-3", ".ac3", ".AC3", (char *)0 },
       .wav_ids = { 0x2000, LQT_WAV_ID_NONE },
-      .compatibility_flags = LQT_FILE_AVI | LQT_FILE_AVI_ODML,
+      .compatibility_flags = LQT_FILE_AVI | LQT_FILE_AVI_ODML | LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_FILE_MP4,
       .do_encode = 1,
+      .compression_id = LQT_COMPRESSION_AC3,
     },
     {
       .id = CODEC_ID_QDM2,
@@ -938,6 +996,7 @@ static void set_codec_info(struct CODECIDMAP * map)
 
   codec_info_ffmpeg.fourccs = map->fourccs;
   codec_info_ffmpeg.wav_ids = map->wav_ids;
+  codec_info_ffmpeg.image_sizes = map->image_sizes;
   if(map->encoder && map->decoder)
     {
     codec_info_ffmpeg.direction = LQT_DIRECTION_BOTH;
@@ -946,6 +1005,7 @@ static void set_codec_info(struct CODECIDMAP * map)
     //    capabilities = "Codec";
     codec_info_ffmpeg.compatibility_flags = map->compatibility_flags;
     codec_info_ffmpeg.encoding_colormodels = map->encoding_colormodels;
+    codec_info_ffmpeg.compression_id = map->compression_id;
     }
   else if(map->encoder)
     {
@@ -954,6 +1014,7 @@ static void set_codec_info(struct CODECIDMAP * map)
     codec_info_ffmpeg.decoding_parameters = NULL;
     codec_info_ffmpeg.compatibility_flags = map->compatibility_flags;
     codec_info_ffmpeg.encoding_colormodels = map->encoding_colormodels;
+    codec_info_ffmpeg.compression_id = map->compression_id;
 
     //    capabilities = "Encoder";
     }
@@ -1018,17 +1079,31 @@ LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
 */
 
 #define IFUNC(x) \
-static void quicktime_init_video_codec_ffmpeg ## x(quicktime_video_map_t *vtrack) \
-{ \
-	int i; \
-	for(i = 0; i < ffmpeg_num_video_codecs; i++) { \
-		if(codecidmap_v[i].index == x) { \
-                     quicktime_init_video_codec_ffmpeg(vtrack, \
-				codecidmap_v[i].encoder, \
-				codecidmap_v[i].decoder); \
-		} \
-	} \
-}
+static void quicktime_init_codec_ffmpeg ## x(quicktime_codec_t * codec, \
+                                             quicktime_audio_map_t *atrack, \
+                                             quicktime_video_map_t *vtrack) \
+  {                                                                     \
+  int i;                                                                \
+  for(i = 0; i < ffmpeg_num_video_codecs; i++)                          \
+    {                                                                   \
+    if(codecidmap_v[i].index == x)                                      \
+      {                                                                 \
+      quicktime_init_video_codec_ffmpeg(codec, vtrack,                  \
+                                        codecidmap_v[i].encoder,        \
+                                        codecidmap_v[i].decoder);       \
+      }                                                                 \
+    }                                                                   \
+  for(i = 0; i < ffmpeg_num_audio_codecs; i++)                          \
+    {                                                                   \
+    if(codecidmap_a[i].index == x)                                      \
+      {                                                                 \
+      quicktime_init_audio_codec_ffmpeg(codec, atrack,                  \
+                                        codecidmap_a[i].encoder,        \
+                                        codecidmap_a[i].decoder);       \
+      }                                                                 \
+    }                                                                   \
+  }
+
 IFUNC(0)
 IFUNC(1)
 IFUNC(2)
@@ -1071,173 +1146,61 @@ IFUNC(38)
 IFUNC(39)
 IFUNC(40)
 #undef IFUNC
-#define MAX_VIDEO_FUNC 40
-#define IFUNC(x) \
-static void quicktime_init_audio_codec_ffmpeg ## x(quicktime_audio_map_t *atrack) \
-{ \
-	int i; \
-	for(i = 0; i < ffmpeg_num_audio_codecs; i++) { \
-		if(codecidmap_a[i].index == x) { \
-                      quicktime_init_audio_codec_ffmpeg(atrack, \
-				codecidmap_a[i].encoder, \
-				codecidmap_a[i].decoder); \
-		} \
-	} \
-}
-IFUNC(0)
-IFUNC(1)
-IFUNC(2)
-IFUNC(3)
-IFUNC(4)
-IFUNC(5)
-IFUNC(6)
-IFUNC(7)
-IFUNC(8)
-IFUNC(9)
-IFUNC(10)
-IFUNC(11)
-IFUNC(12)
-IFUNC(13)
-IFUNC(14)
-IFUNC(15)
-IFUNC(16)
-IFUNC(17)
-IFUNC(18)
-IFUNC(19)
-IFUNC(20)
-IFUNC(21)
-IFUNC(22)
-IFUNC(23)
-IFUNC(24)
-IFUNC(25)
-IFUNC(26)
-IFUNC(27)
-IFUNC(28)
-IFUNC(29)
-IFUNC(30)
-IFUNC(31)
-IFUNC(32)
-IFUNC(33)
-IFUNC(34)
-IFUNC(35)
-IFUNC(36)
-IFUNC(37)
-IFUNC(38)
-IFUNC(39)
-IFUNC(40)
-#define MAX_AUDIO_FUNC 40
+#define MAX_FUNC 40
 
-     
-#undef IFUNC
-
-LQT_EXTERN lqt_init_video_codec_func_t get_video_codec(int index)
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index)
 {
 	ffmpeg_map_init();
-	if(index > MAX_VIDEO_FUNC) {
+	if(index > MAX_FUNC) {
 		lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
-                        "Video index too large: %d", index);
+                        "Codec index too large: %d", index);
 		return NULL;
 	}
 	switch(index) {
-		case 0: return quicktime_init_video_codec_ffmpeg0;
-		case 1: return quicktime_init_video_codec_ffmpeg1;
-		case 2:	return quicktime_init_video_codec_ffmpeg2;
-		case 3:	return quicktime_init_video_codec_ffmpeg3;
-		case 4:	return quicktime_init_video_codec_ffmpeg4;
-		case 5:	return quicktime_init_video_codec_ffmpeg5;
-		case 6:	return quicktime_init_video_codec_ffmpeg6;
-		case 7:	return quicktime_init_video_codec_ffmpeg7;
-		case 8:	return quicktime_init_video_codec_ffmpeg8;
-		case 9:	return quicktime_init_video_codec_ffmpeg9;
-		case 10: return quicktime_init_video_codec_ffmpeg10;
-		case 11: return quicktime_init_video_codec_ffmpeg11;
-		case 12: return quicktime_init_video_codec_ffmpeg12;
-		case 13: return quicktime_init_video_codec_ffmpeg13;
-		case 14: return quicktime_init_video_codec_ffmpeg14;
-		case 15: return quicktime_init_video_codec_ffmpeg15;
-		case 16: return quicktime_init_video_codec_ffmpeg16;
-		case 17: return quicktime_init_video_codec_ffmpeg17;
-		case 18: return quicktime_init_video_codec_ffmpeg18;
-		case 19: return quicktime_init_video_codec_ffmpeg19;
-		case 20: return quicktime_init_video_codec_ffmpeg20;
-		case 21: return quicktime_init_video_codec_ffmpeg21;
-		case 22: return quicktime_init_video_codec_ffmpeg22;
-		case 23: return quicktime_init_video_codec_ffmpeg23;
-		case 24: return quicktime_init_video_codec_ffmpeg24;
-		case 25: return quicktime_init_video_codec_ffmpeg25;
-		case 26: return quicktime_init_video_codec_ffmpeg26;
-		case 27: return quicktime_init_video_codec_ffmpeg27;
-		case 28: return quicktime_init_video_codec_ffmpeg28;
-		case 29: return quicktime_init_video_codec_ffmpeg29;
-		case 30: return quicktime_init_video_codec_ffmpeg30;
-		case 31: return quicktime_init_video_codec_ffmpeg31;
-		case 32: return quicktime_init_video_codec_ffmpeg32;
-		case 33: return quicktime_init_video_codec_ffmpeg33;
-		case 34: return quicktime_init_video_codec_ffmpeg34;
-		case 35: return quicktime_init_video_codec_ffmpeg35;
-		case 36: return quicktime_init_video_codec_ffmpeg36;
-		case 37: return quicktime_init_video_codec_ffmpeg37;
-		case 38: return quicktime_init_video_codec_ffmpeg38;
-		case 39: return quicktime_init_video_codec_ffmpeg39;
-		case 40: return quicktime_init_video_codec_ffmpeg40;
+		case 0: return quicktime_init_codec_ffmpeg0;
+		case 1: return quicktime_init_codec_ffmpeg1;
+		case 2:	return quicktime_init_codec_ffmpeg2;
+		case 3:	return quicktime_init_codec_ffmpeg3;
+		case 4:	return quicktime_init_codec_ffmpeg4;
+		case 5:	return quicktime_init_codec_ffmpeg5;
+		case 6:	return quicktime_init_codec_ffmpeg6;
+		case 7:	return quicktime_init_codec_ffmpeg7;
+		case 8:	return quicktime_init_codec_ffmpeg8;
+		case 9:	return quicktime_init_codec_ffmpeg9;
+		case 10: return quicktime_init_codec_ffmpeg10;
+		case 11: return quicktime_init_codec_ffmpeg11;
+		case 12: return quicktime_init_codec_ffmpeg12;
+		case 13: return quicktime_init_codec_ffmpeg13;
+		case 14: return quicktime_init_codec_ffmpeg14;
+		case 15: return quicktime_init_codec_ffmpeg15;
+		case 16: return quicktime_init_codec_ffmpeg16;
+		case 17: return quicktime_init_codec_ffmpeg17;
+		case 18: return quicktime_init_codec_ffmpeg18;
+		case 19: return quicktime_init_codec_ffmpeg19;
+		case 20: return quicktime_init_codec_ffmpeg20;
+		case 21: return quicktime_init_codec_ffmpeg21;
+		case 22: return quicktime_init_codec_ffmpeg22;
+		case 23: return quicktime_init_codec_ffmpeg23;
+		case 24: return quicktime_init_codec_ffmpeg24;
+		case 25: return quicktime_init_codec_ffmpeg25;
+		case 26: return quicktime_init_codec_ffmpeg26;
+		case 27: return quicktime_init_codec_ffmpeg27;
+		case 28: return quicktime_init_codec_ffmpeg28;
+		case 29: return quicktime_init_codec_ffmpeg29;
+		case 30: return quicktime_init_codec_ffmpeg30;
+		case 31: return quicktime_init_codec_ffmpeg31;
+		case 32: return quicktime_init_codec_ffmpeg32;
+		case 33: return quicktime_init_codec_ffmpeg33;
+		case 34: return quicktime_init_codec_ffmpeg34;
+		case 35: return quicktime_init_codec_ffmpeg35;
+		case 36: return quicktime_init_codec_ffmpeg36;
+		case 37: return quicktime_init_codec_ffmpeg37;
+		case 38: return quicktime_init_codec_ffmpeg38;
+		case 39: return quicktime_init_codec_ffmpeg39;
+		case 40: return quicktime_init_codec_ffmpeg40;
 		default:
 			break;
 	}
-	return (lqt_init_video_codec_func_t)0;
+	return (lqt_init_codec_func_t)0;
 }
 
-LQT_EXTERN lqt_init_audio_codec_func_t get_audio_codec(int index)
-{
-	ffmpeg_map_init();
-	if(index > MAX_AUDIO_FUNC) {
-		lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
-                        "Audio index too large: %d", index);
-		return NULL;
-	}
-	switch(index) {
-		case 0: return quicktime_init_audio_codec_ffmpeg0;
-		case 1: return quicktime_init_audio_codec_ffmpeg1;
-		case 2:	return quicktime_init_audio_codec_ffmpeg2;
-		case 3:	return quicktime_init_audio_codec_ffmpeg3;
-		case 4:	return quicktime_init_audio_codec_ffmpeg4;
-		case 5:	return quicktime_init_audio_codec_ffmpeg5;
-		case 6:	return quicktime_init_audio_codec_ffmpeg6;
-		case 7:	return quicktime_init_audio_codec_ffmpeg7;
-		case 8:	return quicktime_init_audio_codec_ffmpeg8;
-		case 9:	return quicktime_init_audio_codec_ffmpeg9;
-		case 10: return quicktime_init_audio_codec_ffmpeg10;
-		case 11: return quicktime_init_audio_codec_ffmpeg11;
-		case 12: return quicktime_init_audio_codec_ffmpeg12;
-		case 13: return quicktime_init_audio_codec_ffmpeg13;
-		case 14: return quicktime_init_audio_codec_ffmpeg14;
-		case 15: return quicktime_init_audio_codec_ffmpeg15;
-		case 16: return quicktime_init_audio_codec_ffmpeg16;
-		case 17: return quicktime_init_audio_codec_ffmpeg17;
-		case 18: return quicktime_init_audio_codec_ffmpeg18;
-		case 19: return quicktime_init_audio_codec_ffmpeg19;
-		case 20: return quicktime_init_audio_codec_ffmpeg20;
-		case 21: return quicktime_init_audio_codec_ffmpeg21;
-		case 22: return quicktime_init_audio_codec_ffmpeg22;
-		case 23: return quicktime_init_audio_codec_ffmpeg23;
-		case 24: return quicktime_init_audio_codec_ffmpeg24;
-		case 25: return quicktime_init_audio_codec_ffmpeg25;
-		case 26: return quicktime_init_audio_codec_ffmpeg26;
-		case 27: return quicktime_init_audio_codec_ffmpeg27;
-		case 28: return quicktime_init_audio_codec_ffmpeg28;
-		case 29: return quicktime_init_audio_codec_ffmpeg29;
-                case 30: return quicktime_init_audio_codec_ffmpeg30;
-		case 31: return quicktime_init_audio_codec_ffmpeg31;
-		case 32: return quicktime_init_audio_codec_ffmpeg32;
-		case 33: return quicktime_init_audio_codec_ffmpeg33;
-		case 34: return quicktime_init_audio_codec_ffmpeg34;
-		case 35: return quicktime_init_audio_codec_ffmpeg35;
-		case 36: return quicktime_init_audio_codec_ffmpeg36;
-		case 37: return quicktime_init_audio_codec_ffmpeg37;
-		case 38: return quicktime_init_audio_codec_ffmpeg38;
-		case 39: return quicktime_init_audio_codec_ffmpeg39;
-		case 40: return quicktime_init_audio_codec_ffmpeg40;
-		default:
-			break;
-	}
-	return (lqt_init_audio_codec_func_t)0;
-}
