@@ -28,7 +28,6 @@
 
 #include "qtpng.h"
 
-void quicktime_init_codec_png(quicktime_video_map_t *vtrack);
 
 static char * fourccs_png[]  = { QUICKTIME_PNG, (char*)0 };
 
@@ -59,6 +58,7 @@ static lqt_codec_info_static_t codec_info_pngalpha =
   .encoding_parameters = encode_parameters_png,
   .decoding_parameters = (lqt_parameter_info_static_t*)0,
   .compatibility_flags = LQT_FILE_QT_OLD | LQT_FILE_QT | LQT_CODEC_OBSOLETE,
+  .compression_id      = LQT_COMPRESSION_PNG,
   };
 
 static lqt_codec_info_static_t codec_info_png =
@@ -75,6 +75,7 @@ static lqt_codec_info_static_t codec_info_png =
   .encoding_colormodels = (int[]) { BC_RGB888,
                                     BC_RGBA8888,
                                     LQT_COLORMODEL_NONE},
+  .compression_id      = LQT_COMPRESSION_PNG,
   };
 
 /* These are called from the plugin loader */
@@ -93,19 +94,12 @@ LQT_EXTERN lqt_codec_info_static_t * get_codec_info(int index)
   return (lqt_codec_info_static_t*)0;
   }
 
-/*
- * This is missing in qtpng.h, so we add it here to leave the original
- * source untouched
- */
-
-void quicktime_init_codec_png(quicktime_video_map_t *vtrack);
-void quicktime_init_codec_pngalpha(quicktime_video_map_t *vtrack);
 
 /*
  *   Return the actual codec constructor
  */
 
-LQT_EXTERN lqt_init_video_codec_func_t get_video_codec(int index)
+LQT_EXTERN lqt_init_codec_func_t get_codec(int index)
   {
   switch(index)
     {
@@ -116,5 +110,5 @@ LQT_EXTERN lqt_init_video_codec_func_t get_video_codec(int index)
       return quicktime_init_codec_pngalpha;
       break;
     }
-  return (lqt_init_video_codec_func_t)0;
+  return (lqt_init_codec_func_t)0;
   }
