@@ -44,11 +44,13 @@ typedef struct
   } quicktime_png_codec_t;
 
 
-static int delete_codec(quicktime_video_map_t *vtrack)
+static int delete_codec(quicktime_codec_t *codec_base)
   {
-  quicktime_png_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-  if(codec->buffer) free(codec->buffer);
-  if(codec->temp_frame) free(codec->temp_frame);
+  quicktime_png_codec_t *codec = codec_base->priv;
+  if(codec->buffer)
+    free(codec->buffer);
+  if(codec->temp_frame)
+    free(codec->temp_frame);
   free(codec);
   return 0;
   }
@@ -62,21 +64,6 @@ static int source_cmodel(quicktime_t *file, int track)
     return BC_RGBA8888;
   }
 
-#if 0
-void quicktime_set_png(quicktime_t *file, int compression_level)
-  {
-  int i;
-
-  for(i = 0; i < file->total_vtracks; i++)
-    {
-    if(quicktime_match_32(quicktime_video_compressor(file, i), QUICKTIME_PNG))
-      {
-      quicktime_png_codec_t *codec = ((quicktime_codec_t*)file->vtracks[i].codec)->priv;
-      codec->compression_level = compression_level;
-      }
-    }
-  }
-#endif
 
 static void read_function(png_structp png_ptr, png_bytep data, png_uint_32 length)
   {
@@ -109,15 +96,19 @@ static void flush_function(png_structp png_ptr)
 static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
   {
   int result = 0;
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
   png_structp png_ptr;
   png_infop info_ptr;
   png_infop end_info = 0;	
-  quicktime_png_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_png_codec_t *codec = vtrack->codec->priv;
 
   if(!row_pointers)
     {
     vtrack->stream_cmodel = source_cmodel(file, track);
+
+    /* Set compression info */
+    vtrack->ci.id = LQT_COMPRESSION_PNG;
+    
     return 0;
     }
 
@@ -144,9 +135,9 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
   {
   int result = 0;
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
   quicktime_trak_t *trak = vtrack->track;
-  quicktime_png_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_png_codec_t *codec = vtrack->codec->priv;
   int height = trak->tkhd.track_height;
   int width = trak->tkhd.track_width;
   png_structp png_ptr;
@@ -154,7 +145,8 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 
   if(!row_pointers)
     {
-    // vtrack->stream_cmodel = source_cmodel(file, track);
+    if(vtrack->ci.id)
+      vtrack->stream_cmodel = vtrack->ci.colormodel;
     return 0;
     }
 
@@ -205,6 +197,7 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
   result = !quicktime_write_data(file, 
                                  codec->buffer, 
                                  codec->buffer_size);
+
   lqt_write_frame_footer(file, track);
   return result;
   }
@@ -215,33 +208,55 @@ static int set_parameter(quicktime_t *file,
                          const char *key, 
                          const void *value)
   {
-  quicktime_png_codec_t *codec = ((quicktime_codec_t*)file->vtracks[track].codec)->priv;
+  quicktime_png_codec_t *codec = file->vtracks[track].codec->priv;
   
   if(!strcasecmp(key, "png_compression_level"))
     codec->compression_level = *(int*)value;
   return 0;
   }
 
-void quicktime_init_codec_png(quicktime_video_map_t *vtrack)
+static int writes_compressed(lqt_file_type_t type, const lqt_compression_info_t * ci)
+  {
+  if(!(type & (LQT_FILE_QT | LQT_FILE_QT_OLD)))
+    return 0;
+
+  if((ci->colormodel != BC_RGB888) && (ci->colormodel != BC_RGBA8888))
+    return 0;
+  return 1;
+  }
+
+void quicktime_init_codec_png(quicktime_codec_t * codec_base,
+                              quicktime_audio_map_t *atrack,
+                              quicktime_video_map_t *vtrack)
   {
   quicktime_png_codec_t *codec;
 
+  codec = calloc(1, sizeof(*codec));
+  
   /* Init public items */
-  ((quicktime_codec_t*)vtrack->codec)->priv = calloc(1, sizeof(quicktime_png_codec_t));
-  ((quicktime_codec_t*)vtrack->codec)->delete_vcodec = delete_codec;
-  ((quicktime_codec_t*)vtrack->codec)->decode_video = decode;
-  ((quicktime_codec_t*)vtrack->codec)->encode_video = encode;
-  ((quicktime_codec_t*)vtrack->codec)->set_parameter = set_parameter;
+  codec_base->priv = codec;
+  codec_base->delete_codec = delete_codec;
+  codec_base->decode_video = decode;
+  codec_base->encode_video = encode;
+  codec_base->set_parameter = set_parameter;
+  codec_base->writes_compressed = writes_compressed;
   
   /* Init private items */
-  codec = ((quicktime_codec_t*)vtrack->codec)->priv;
   codec->compression_level = 9;
+
+  if(!vtrack)
+    return;
   vtrack->stream_cmodel = BC_RGB888;
   }
 
-void quicktime_init_codec_pngalpha(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_pngalpha(quicktime_codec_t * codec_base,
+                                   quicktime_audio_map_t *atrack,
+                                   quicktime_video_map_t *vtrack)
   {
   /* Proceed as normal */
-  quicktime_init_codec_png(vtrack);
+  quicktime_init_codec_png(codec_base, atrack, vtrack);
+  
+  if(!vtrack)
+    return;
   vtrack->stream_cmodel = BC_RGBA8888;
   }
