@@ -21,5 +21,11 @@
  with this library; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *******************************************************************************/ 
-void quicktime_init_codec_png(quicktime_video_map_t *vtrack);
-void quicktime_init_codec_pngalpha(quicktime_video_map_t *vtrack);
+
+void quicktime_init_codec_png(quicktime_codec_t * codec_base,
+                              quicktime_audio_map_t *atrack,
+                              quicktime_video_map_t *vtrack);
+
+void quicktime_init_codec_pngalpha(quicktime_codec_t * codec_base,
+                                   quicktime_audio_map_t *atrack,
+                                   quicktime_video_map_t *vtrack);
