@@ -26,7 +26,7 @@
 
 #define LQT_LIBQUICKTIME /* Hack: This prevents multiple compilation of
                             get_codec_api_version() */
-
+#include "lqt_private.h"
 #include "schroedinger.h"
 #include <quicktime/colormodels.h>
 
@@ -119,10 +119,10 @@ lqt_schrodinger_get_frame_format(SchroVideoFormat *format)
     return 0;
   }
 
-int lqt_schroedinger_delete(quicktime_video_map_t *vtrack)
+int lqt_schroedinger_delete(quicktime_codec_t *codec_base)
   {
-  schroedinger_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-
+  schroedinger_codec_t *codec = codec_base->priv;
+  
   if(codec->dec)
     schro_decoder_free(codec->dec);
   if(codec->dec_buffer)
@@ -147,7 +147,9 @@ static int set_parameter_schroedinger(quicktime_t *file,
   return 0;
   }
 
-void quicktime_init_codec_schroedinger(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_schroedinger(quicktime_codec_t * codec_base,
+                                       quicktime_audio_map_t *atrack,
+                                       quicktime_video_map_t *vtrack)
   {
   schroedinger_codec_t *codec;
   
@@ -162,15 +164,15 @@ void quicktime_init_codec_schroedinger(quicktime_video_map_t *vtrack)
   /* Need to create the encoder immediately */
   codec->enc = schro_encoder_new();
   
-  ((quicktime_codec_t*)vtrack->codec)->priv = (void *)codec;
-  ((quicktime_codec_t*)vtrack->codec)->delete_vcodec = lqt_schroedinger_delete;
-  ((quicktime_codec_t*)vtrack->codec)->flush = lqt_schroedinger_flush;
-  ((quicktime_codec_t*)vtrack->codec)->resync = lqt_schroedinger_resync;
+  codec_base->priv = (void *)codec;
+  codec_base->delete_codec = lqt_schroedinger_delete;
+  codec_base->flush = lqt_schroedinger_flush;
+  codec_base->resync = lqt_schroedinger_resync;
   
-  ((quicktime_codec_t*)vtrack->codec)->encode_video = lqt_schroedinger_encode_video;
+  codec_base->encode_video = lqt_schroedinger_encode_video;
   
-  ((quicktime_codec_t*)vtrack->codec)->decode_video = lqt_schroedinger_decode_video;
-  ((quicktime_codec_t*)vtrack->codec)->set_parameter = set_parameter_schroedinger;
+  codec_base->decode_video = lqt_schroedinger_decode_video;
+  codec_base->set_parameter = set_parameter_schroedinger;
   
   }
 
