@@ -22,6 +22,8 @@
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *******************************************************************************/ 
 
+#include <stdio.h>
+
 #include "lqt_private.h"
 #include <quicktime/colormodels.h>
 #include <stdlib.h>
@@ -197,29 +199,16 @@ static void scanline_raw_32(uint8_t * src,
 
 /* */
 
-static int quicktime_delete_codec_raw(quicktime_video_map_t *vtrack)
-{
-	quicktime_raw_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-#if 0
-	if(codec->temp_frame)
-	{
-		free(codec->temp_frame);
-	}
-	if(codec->temp_rows)
-	{
-		free(codec->temp_rows);
-	}
-#endif
-	if(codec->buffer)
-	{
-		free(codec->buffer);
-	}
+static int quicktime_delete_codec_raw(quicktime_codec_t *codec_base)
+  {
+  quicktime_raw_codec_t *codec = codec_base->priv;
+  if(codec->buffer)
+    free(codec->buffer);
+  
+  free(codec);
+  return 0;
+  }
 
-	free(codec);
-	return 0;
-}
-
-#include <stdio.h>
 
 static int source_cmodel(quicktime_t *file, int track)
 {
@@ -241,7 +230,7 @@ static int quicktime_decode_raw(quicktime_t *file, unsigned char **row_pointers,
   int i;
   unsigned char *ptr;
   quicktime_ctab_t * ctab;
-  quicktime_raw_codec_t *codec = ((quicktime_codec_t*)file->vtracks[track].codec)->priv;
+  quicktime_raw_codec_t *codec = file->vtracks[track].codec->priv;
         
   if(!row_pointers)
     {
@@ -249,7 +238,7 @@ static int quicktime_decode_raw(quicktime_t *file, unsigned char **row_pointers,
     return 0;
     }
         
-  ctab = &(trak->mdia.minf.stbl.stsd.table->ctab);
+  ctab = &trak->mdia.minf.stbl.stsd.table->ctab;
                 
         
   if(!codec->scanline_func)
@@ -353,12 +342,12 @@ static int quicktime_encode_raw(quicktime_t *file,
   int i, j;
   uint8_t * in_ptr, *out_ptr;
   uint8_t padd = 0;
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
   quicktime_trak_t *trak = vtrack->track;
   int result = 0;
   int height = trak->tkhd.track_height;
   int width = trak->tkhd.track_width;
-  quicktime_raw_codec_t *codec = ((quicktime_codec_t*)file->vtracks[track].codec)->priv;
+  quicktime_raw_codec_t *codec = file->vtracks[track].codec->priv;
         
   if(!row_pointers)
     {
@@ -420,19 +409,29 @@ static int quicktime_encode_raw(quicktime_t *file,
   return result;
   }
 
-void quicktime_init_codec_raw(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_raw(quicktime_codec_t * codec_base,
+                              quicktime_audio_map_t *atrack,
+                              quicktime_video_map_t *vtrack)
   {
-  quicktime_codec_t *codec_base = (quicktime_codec_t*)vtrack->codec;
- 
+  
   codec_base->priv = calloc(1, sizeof(quicktime_raw_codec_t));
-  codec_base->delete_vcodec = quicktime_delete_codec_raw;
+  codec_base->delete_codec = quicktime_delete_codec_raw;
   codec_base->decode_video = quicktime_decode_raw;
   codec_base->encode_video = quicktime_encode_raw;
+
+  if(!vtrack)
+    return;
+  
   vtrack->stream_cmodel = BC_RGB888;
   }
 
-void quicktime_init_codec_rawalpha(quicktime_video_map_t *vtrack)
+void quicktime_init_codec_rawalpha(quicktime_codec_t * codec_base,
+                                   quicktime_audio_map_t *atrack,
+                                   quicktime_video_map_t *vtrack)
   {
-  quicktime_init_codec_raw(vtrack);
+  quicktime_init_codec_raw(codec_base, atrack, vtrack);
+
+  if(!vtrack)
+    return;
   vtrack->stream_cmodel = BC_RGBA8888;
   }
