@@ -179,9 +179,9 @@ typedef struct
   
   } quicktime_x264_codec_t;
 
-static int delete_codec(quicktime_video_map_t *vtrack)
+static int delete_codec(quicktime_codec_t *codec_base)
   {
-  quicktime_x264_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_x264_codec_t *codec = codec_base->priv;
   if(codec->enc)
     x264_encoder_close(codec->enc);
   
@@ -324,16 +324,12 @@ static int avc_parse_nal_units(uint8_t *src, int src_size,
   return ret_size;
   }
 
-static uint8_t * create_avcc_atom(quicktime_x264_codec_t * codec,
-                                  int * ret_size)
+static void create_avcc_atom(quicktime_t * file, int track, uint8_t *header,
+                             int header_len)
   {
-  int i;
-  x264_nal_t *nal;
-  int nnal;
   uint8_t * ret, *ret_ptr;
-  uint8_t * tmp_buf, *tmp_buf_1 = (uint8_t*)0;
+  uint8_t *tmp_buf_1 = (uint8_t*)0;
   int tmp_buf_alloc_1 = 0;
-  int tmp_size;
   int tmp_size_1;
   
   uint8_t * ptr, *ptr_end;
@@ -341,19 +337,12 @@ static uint8_t * create_avcc_atom(quicktime_x264_codec_t * codec,
   uint32_t sps_size=0, pps_size=0;
   uint8_t *sps=0, *pps=0;
   uint8_t nal_type;
+  int ret_size;
+
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_trak_t *trak = vtrack->track;
   
-  x264_encoder_headers(codec->enc, &nal, &nnal);
-
-  tmp_size = 0;
-
-  /* 5 bytes NAL header + worst case escaping */
-  for(i = 0; i < nnal; i++)
-    tmp_size += 5 + nal[i].i_payload * 4 / 3;
-
-  tmp_buf = malloc(tmp_size);
-  tmp_size = encode_nals(tmp_buf, tmp_size, nal, nnal);
-  
-  tmp_size_1 = avc_parse_nal_units(tmp_buf, tmp_size,
+  tmp_size_1 = avc_parse_nal_units(header, header_len,
                                    &tmp_buf_1, &tmp_buf_alloc_1);
 
   /* Look for sps and pps */
@@ -384,7 +373,7 @@ static uint8_t * create_avcc_atom(quicktime_x264_codec_t * codec,
     ptr += nal_size + 4;
     }
 
-  *ret_size =
+  ret_size =
     6 +        // Initial bytes
     2 +        // sps_size
     sps_size + // sps
@@ -393,7 +382,7 @@ static uint8_t * create_avcc_atom(quicktime_x264_codec_t * codec,
     pps_size;  // pps
 
   
-  ret = malloc(*ret_size);
+  ret = malloc(ret_size);
   ret_ptr = ret;
   
   /* Start encoding */
@@ -426,10 +415,11 @@ static uint8_t * create_avcc_atom(quicktime_x264_codec_t * codec,
   memcpy(ret_ptr, pps, pps_size);
   ret_ptr += pps_size;
 
-  free(tmp_buf);
   free(tmp_buf_1);
-  
-  return ret;
+
+  quicktime_user_atoms_add_atom(&trak->mdia.minf.stbl.stsd.table[0].user_atoms,
+                                "avcC", ret, ret_size);
+  file->moov.iods.videoProfileId = 0x15;
   }
 
 static int flush_frame(quicktime_t *file, int track,
@@ -440,10 +430,10 @@ static int flush_frame(quicktime_t *file, int track,
   int nnal;
   x264_picture_t pic_out;
   int encoded_size;
-  char * ptr;
+  uint8_t * ptr;
   
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_x264_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_x264_codec_t *codec = vtrack->codec->priv;
 
   pic_out.i_pts = 0;
   /* Encode frames, get nals */
@@ -492,9 +482,9 @@ static int set_pass_x264(quicktime_t *file,
                            int track, int pass, int total_passes,
                            const char * stats_file)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
   quicktime_x264_codec_t *codec =
-    ((quicktime_codec_t*)vtrack->codec)->priv;
+    vtrack->codec->priv;
 
   codec->total_passes = total_passes;
   codec->pass = pass;
@@ -565,7 +555,7 @@ x264_do_log( void * priv, int i_level, const char *psz, va_list argp)
 
 static void set_fiel(quicktime_t * file, int track)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
   quicktime_stsd_table_t *stsd;
   
   stsd = vtrack->track->mdia.minf.stbl.stsd.table;
@@ -594,14 +584,11 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
   x264_picture_t pic_in;
 
   int result = 0, pixel_width, pixel_height;
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
   quicktime_trak_t *trak = vtrack->track;
-  quicktime_x264_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_x264_codec_t *codec = vtrack->codec->priv;
   int height = trak->tkhd.track_height;
   int width = trak->tkhd.track_width;
-  uint8_t * avcc;
-  int avcc_size;
-  
   
   if(!row_pointers)
     {
@@ -699,21 +686,35 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
     
     /* Open encoder */
 
-
     codec->enc = x264_encoder_open(&codec->params);
     if(!codec->enc)
       {
       lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "x264_encoder_open failed");
       return 1;
       }
-    
-    /* Encode global header */
-    avcc = create_avcc_atom(codec, &avcc_size);
-    
-    quicktime_user_atoms_add_atom(&(trak->mdia.minf.stbl.stsd.table[0].user_atoms),
-                                  "avcC", avcc, avcc_size);
 
-    file->moov.iods.videoProfileId = 0x15;
+    if(!trak->strl) /* Global header for MOV */
+      {
+      int i;
+      
+      int header_len;
+      uint8_t * header;
+      x264_nal_t *nal;
+      int nnal;
+      
+      x264_encoder_headers(codec->enc, &nal, &nnal);
+      
+      header_len = 0;
+
+      /* 5 bytes NAL header + worst case escaping */
+      for(i = 0; i < nnal; i++)
+        header_len += 5 + nal[i].i_payload * 4 / 3;
+
+      header = malloc(header_len);
+      header_len = encode_nals(header, header_len, nal, nnal);
+      create_avcc_atom(file, track, header, header_len);
+      free(header);
+      }
     
     codec->initialized = 1;
     }
@@ -742,8 +743,8 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 
 static int flush(quicktime_t *file, int track)
   {
-  quicktime_video_map_t *vtrack = &(file->vtracks[track]);
-  quicktime_x264_codec_t *codec = ((quicktime_codec_t*)vtrack->codec)->priv;
+  quicktime_video_map_t *vtrack = &file->vtracks[track];
+  quicktime_x264_codec_t *codec = vtrack->codec->priv;
   
   /* Do nothing if we didn't encode anything yet */
   if(!codec->initialized)
@@ -841,6 +842,21 @@ enum_t aq_modes[] =
   };
 #endif
 
+#if X264_BUILD >= 88
+enum_t b_pyramid_modes[] =
+  {
+    { "None",   X264_B_PYRAMID_NONE },
+    { "Strict", X264_B_PYRAMID_STRICT },
+    { "Normal", X264_B_PYRAMID_NORMAL },
+  };
+
+enum_t weighted_pred_modes[] =
+  {
+    { "Disabled",       X264_WEIGHTP_NONE },
+    { "Blind offset",   X264_WEIGHTP_BLIND },
+    { "Smart analysis", X264_WEIGHTP_SMART },
+  };
+#endif
 
 static int set_parameter(quicktime_t *file, 
                          int track, 
@@ -848,7 +864,7 @@ static int set_parameter(quicktime_t *file,
                          const void *value)
   {
   int found = 0, i;
-  quicktime_x264_codec_t *codec = ((quicktime_codec_t*)file->vtracks[track].codec)->priv;
+  quicktime_x264_codec_t *codec = file->vtracks[track].codec->priv;
 #if X264_BUILD >= 28
   INTPARAM("x264_i_threads", codec->params.i_threads);
 #endif
@@ -864,6 +880,11 @@ static int set_parameter(quicktime_t *file,
   INTPARAM("x264_i_bframe_bias", codec->params.i_bframe_bias);
 #if X264_BUILD >= 78
   INTPARAM("x264_i_bframe_pyramid", codec->params.i_bframe_pyramid);
+#elif X264_BUILD >= 88
+  ENUMPARAM("x264_i_bframe_pyramid", codec->params.i_bframe_pyramid, b_pyramid_modes);
+  ENUMPARAM("x264_i_weighted_pred", codec->params.analyse.i_weighted_pred, weighted_pred_modes);
+  INTPARAM("x264_b_fast_pskip", codec->params.analyse.b_fast_pskip);
+  INTPARAM("x264_b_dct_decimate", codec->params.analyse.b_dct_decimate);
 #else
   INTPARAM("x264_b_bframe_pyramid", codec->params.b_bframe_pyramid);
 #endif
@@ -877,6 +898,7 @@ static int set_parameter(quicktime_t *file,
 #else
   FLOATPARAM("x264_f_rf_constant", codec->params.rc.f_rf_constant);
 #endif
+  
   INTPARAM("x264_i_qp_min", codec->params.rc.i_qp_min);
   INTPARAM("x264_i_qp_max", codec->params.rc.i_qp_max);
   INTPARAM("x264_i_qp_step", codec->params.rc.i_qp_step);
@@ -899,6 +921,16 @@ static int set_parameter(quicktime_t *file,
   
   INTPARAM("x264_analyse_8x8_transform", codec->params.analyse.b_transform_8x8);
 
+#if X264_BUILD >= 88
+  FLOATPARAM("x264_f_qcompress", codec->params.rc.f_qcompress);
+  FLOATPARAM("x264_f_qblur", codec->params.rc.f_qblur);
+  FLOATPARAM("x264_f_complexity_blur", codec->params.rc.f_complexity_blur);
+  INTPARAM("x264_i_chroma_qp_offset", codec->params.analyse.i_chroma_qp_offset);
+
+  INTPARAM("x264_i_luma_deadzone_0", codec->params.analyse.i_luma_deadzone[0]);
+  INTPARAM("x264_i_luma_deadzone_1", codec->params.analyse.i_luma_deadzone[1]);
+#endif
+  
   if(!strcasecmp(key, "x264_analyse_psub16x16"))
     {
     if(*(int*)(value))
@@ -992,6 +1024,10 @@ static int set_parameter(quicktime_t *file,
 #if X264_BUILD >= 63
   FLOATPARAM("x264_f_psy_rd", codec->params.analyse.f_psy_rd);
   FLOATPARAM("x264_f_psy_trellis", codec->params.analyse.f_psy_trellis);
+#endif
+#if X264_BUILD >= 69
+  INTPARAM("x264_b_psy", codec->params.analyse.b_psy);
+  
 #endif
   
   if(!found)
@@ -1001,23 +1037,70 @@ static int set_parameter(quicktime_t *file,
   return 0;
   }
 
-void quicktime_init_codec_x264(quicktime_video_map_t *vtrack)
+static int init_compressed(quicktime_t * file, int track)
   {
+  create_avcc_atom(file, track,
+                   file->vtracks[track].ci.global_header,
+                   file->vtracks[track].ci.global_header_len);
+  return 0;
+  }
+
+static int write_packet(quicktime_t * file, lqt_packet_t * p, int track)
+  {
+  int result;
+  quicktime_video_map_t * vtrack = &file->vtracks[track];
+  quicktime_x264_codec_t *codec = vtrack->codec->priv;
+  
+  /* AVI case: Prepend header to keyframe */
+  if(file->file_type & (LQT_FILE_AVI | LQT_FILE_AVI_ODML)) 
+    {
+    if(p->flags & LQT_PACKET_KEYFRAME)
+      result = !quicktime_write_data(file, vtrack->ci.global_header,
+                                     vtrack->ci.global_header_len);
+
+    if(!codec->initialized)
+      {
+      strncpy(vtrack->track->strl->strh.fccHandler, "H264", 4);
+      strncpy(vtrack->track->strl->strf.bh.biCompression, "H264", 4);
+      codec->initialized = 1;
+      }
+    result = !quicktime_write_data(file, p->data, p->data_len);
+    }
+  /* MOV case: Reformat stream */
+  else
+    {
+    int encoded_size;
+    encoded_size = avc_parse_nal_units(p->data,
+                                       p->data_len,
+                                       &codec->work_buffer_1,
+                                       &codec->work_buffer_alloc_1);
+    result = !quicktime_write_data(file, codec->work_buffer_1, encoded_size);
+    }
+  
+  return result;
+  }
+
+
+
+void quicktime_init_codec_x264(quicktime_codec_t * codec_base,
+                               quicktime_audio_map_t *atrack,
+                               quicktime_video_map_t *vtrack)
+  {
   quicktime_x264_codec_t *codec;
+
+  codec = calloc(1, sizeof(*codec));
+  /* Init public items */
+  codec_base->priv = codec;
+  codec_base->delete_codec = delete_codec;
+  codec_base->encode_video = encode;
+  codec_base->set_pass = set_pass_x264;
+  codec_base->flush = flush;
+  codec_base->set_parameter = set_parameter;
+  codec_base->init_compressed = init_compressed;
+  codec_base->write_packet = write_packet;
   
-  /* Init public items */
-  ((quicktime_codec_t*)vtrack->codec)->priv = calloc(1, sizeof(quicktime_x264_codec_t));
-  ((quicktime_codec_t*)vtrack->codec)->delete_vcodec = delete_codec;
-  ((quicktime_codec_t*)vtrack->codec)->encode_video = encode;
-  ((quicktime_codec_t*)vtrack->codec)->set_pass = set_pass_x264;
-  ((quicktime_codec_t*)vtrack->codec)->flush = flush;
-  ((quicktime_codec_t*)vtrack->codec)->decode_video = 0;
-  ((quicktime_codec_t*)vtrack->codec)->set_parameter = set_parameter;
-  ((quicktime_codec_t*)vtrack->codec)->decode_audio = 0;
-  ((quicktime_codec_t*)vtrack->codec)->encode_audio = 0;
   
   /* Init private items */
-  codec = ((quicktime_codec_t*)vtrack->codec)->priv;
-  x264_param_default(&(codec->params));
+  x264_param_default(&codec->params);
   }
 
