@@ -83,6 +83,7 @@ static const char * num_wav_ids_key     = "NumWavIds: ";
 static const char * wav_ids_key         = "WavIds: ";
 
 static const char * compatibility_key   = "Compatibility: ";
+static const char * compression_id_key  = "CompressionID: ";
 
 /* Module filename and module index */
 
@@ -127,6 +128,12 @@ num_encoding_colormodels_key = "NumEncodingColormodels: ";
 static const char *
 encoding_colormodel_key =      "EncodingColormodel: "; 	 
 
+static const char *
+num_image_sizes_key = "NumImageSizes: "; 	 
+
+static const char *
+image_size_key =      "ImageSize: "; 	 
+
 /* Codec order */
 
 static const char * audio_order_key = "AudioOrder: ";
@@ -310,7 +317,7 @@ static void read_parameter_info(FILE * input,
     else if(CHECK_KEYWORD(value_key))
       {
       pos = line + strlen(value_key);
-      read_parameter_value(pos, &(info->val_default), info->type);
+      read_parameter_value(pos, &info->val_default, info->type);
       }
 
     else if(CHECK_KEYWORD(min_value_key))
@@ -376,6 +383,7 @@ static void read_codec_info(FILE * input, lqt_codec_info_t * codec,
   int encoding_parameters_read = 0;
   int decoding_parameters_read = 0;
   int encoding_colormodels_read = 0;
+  int image_sizes_read = 0;
   
   uint32_t tmp_fourcc;
   
@@ -420,6 +428,15 @@ static void read_codec_info(FILE * input, lqt_codec_info_t * codec,
         codec->type = LQT_CODEC_VIDEO;
       }
 
+    /* Compression ID */
+
+    else if(CHECK_KEYWORD(compression_id_key))
+      {
+      pos = line + strlen(compression_id_key);
+      codec->compression_id =
+        lqt_compression_id_from_string(pos);
+      }
+    
     /* Direction */
    
     else if(CHECK_KEYWORD(direction_key))
@@ -543,8 +560,8 @@ static void read_codec_info(FILE * input, lqt_codec_info_t * codec,
       codec->num_encoding_colormodels = atoi(pos);
       if(codec->num_encoding_colormodels)
         codec->encoding_colormodels =
-          malloc(codec->num_encoding_colormodels *
-                 sizeof(int));
+          malloc((codec->num_encoding_colormodels+1) *
+                 sizeof(*codec->encoding_colormodels));
       else 	 
         codec->encoding_colormodels = (int*)0; 	 
       } 	 
@@ -558,6 +575,31 @@ static void read_codec_info(FILE * input, lqt_codec_info_t * codec,
         lqt_string_to_colormodel(pos);
       encoding_colormodels_read++; 
       }
+
+    /* Number of image sizes */ 	 
+    
+    else if(CHECK_KEYWORD(num_image_sizes_key))
+      {
+      pos = line + strlen(num_image_sizes_key);
+      codec->num_image_sizes = atoi(pos);
+      if(codec->num_image_sizes)
+        codec->image_sizes =
+          malloc(codec->num_image_sizes *
+                 sizeof(*codec->image_sizes));
+      else 	 
+        codec->image_sizes = NULL; 	 
+      } 	 
+
+    /* Image size */ 	 
+
+    else if(CHECK_KEYWORD(image_size_key)) 	 
+      {
+      pos = line + strlen(image_size_key);
+
+      sscanf(pos, "%d %d", &codec->image_sizes[image_sizes_read].width,
+             &codec->image_sizes[image_sizes_read].height);
+      image_sizes_read++; 
+      }
     
     /* Number of parameters */
 
@@ -592,7 +634,7 @@ static void read_codec_info(FILE * input, lqt_codec_info_t * codec,
     else if(CHECK_KEYWORD(begin_parameter_e_key))
       {
       read_parameter_info(input,
-                          &(codec->encoding_parameters[encoding_parameters_read]),
+                          &codec->encoding_parameters[encoding_parameters_read],
                           line);
       encoding_parameters_read++;
       }
@@ -600,7 +642,7 @@ static void read_codec_info(FILE * input, lqt_codec_info_t * codec,
     else if(CHECK_KEYWORD(begin_parameter_d_key))
       {
       read_parameter_info(input,
-                     &(codec->decoding_parameters[decoding_parameters_read]),
+                     &codec->decoding_parameters[decoding_parameters_read],
                      line);
       decoding_parameters_read++;
       }
@@ -742,7 +784,7 @@ static void write_parameter_info(FILE * output,
     }
 
   fprintf(output, "%s%s\n", type_key, tmp);
-
+  
   /*
    *   Print the value
    */
@@ -827,6 +869,12 @@ static int write_codec_info(const lqt_codec_info_t * info, FILE * output)
 
   if(tmp)
     fprintf(output, "%s%s\n", type_key, tmp);
+
+  if(info->compression_id != LQT_COMPRESSION_NONE)
+    {
+    fprintf(output, "%s%s\n", compression_id_key,
+            lqt_compression_id_to_string(info->compression_id));
+    }
   
   switch(info->direction)
     {
@@ -872,7 +920,7 @@ static int write_codec_info(const lqt_codec_info_t * info, FILE * output)
 
   for(i = 0; i < info->num_encoding_parameters; i++)
     {
-    write_parameter_info(output, &(info->encoding_parameters[i]), 1);
+    write_parameter_info(output, &info->encoding_parameters[i], 1);
     }
 
   fprintf(output, "%s%d\n", num_decoding_parameters_key,
@@ -880,7 +928,7 @@ static int write_codec_info(const lqt_codec_info_t * info, FILE * output)
     
   for(i = 0; i < info->num_decoding_parameters; i++)
     {
-    write_parameter_info(output, &(info->decoding_parameters[i]), 0);
+    write_parameter_info(output, &info->decoding_parameters[i], 0);
     }
   
   if((info->type == LQT_CODEC_VIDEO) &&
@@ -895,6 +943,18 @@ static int write_codec_info(const lqt_codec_info_t * info, FILE * output)
               lqt_colormodel_to_string(info->encoding_colormodels[i]));
       }
     }
+
+  if((info->type == LQT_CODEC_VIDEO) &&
+     (info->direction != LQT_DIRECTION_DECODE))
+    {
+    fprintf(output, "%s%d\n", num_image_sizes_key,
+            info->num_image_sizes);
+    for(i = 0; i < info->num_image_sizes; i++)
+      {
+      fprintf(output, "%s%d %d\n", image_size_key,
+              info->image_sizes[i].width, info->image_sizes[i].height);
+      }
+    }
   
   /* Module filename and index */
   fprintf(output, "%s%s\n", module_filename_key, info->module_filename);
