@@ -134,7 +134,7 @@ static void destroy_parameter_info(lqt_parameter_info_t * p)
 
 /* Free memory of codec info (public) */
 
-static void destroy_codec_info(lqt_codec_info_t * ptr)
+void lqt_codec_info_destroy_single(lqt_codec_info_t * ptr)
   {
   int i;
 
@@ -167,16 +167,18 @@ static void destroy_codec_info(lqt_codec_info_t * ptr)
   if(ptr->encoding_parameters)
     {
     for(i = 0; i < ptr->num_encoding_parameters; i++)
-      destroy_parameter_info(&(ptr->encoding_parameters[i]));
+      destroy_parameter_info(&ptr->encoding_parameters[i]);
     free(ptr->encoding_parameters);
     }
 
   if(ptr->decoding_parameters)
     {
     for(i = 0; i < ptr->num_decoding_parameters; i++)
-      destroy_parameter_info(&(ptr->decoding_parameters[i]));
+      destroy_parameter_info(&ptr->decoding_parameters[i]);
     free(ptr->decoding_parameters);
     }
+  if(ptr->image_sizes)
+    free(ptr->image_sizes);
   free(ptr);
   }
 
@@ -257,8 +259,8 @@ copy_parameter_info(lqt_parameter_info_t * ret,
       break;
     }
 
-  copy_parameter_value(&(ret->val_default),
-                       &(info->val_default),
+  copy_parameter_value(&ret->val_default,
+                       &info->val_default,
                        info->type);
 
   }
@@ -267,12 +269,11 @@ copy_parameter_info(lqt_parameter_info_t * ret,
  *  Copy codec Info
  */
 
-static lqt_codec_info_t *
-copy_codec_info(const lqt_codec_info_t * info)
+lqt_codec_info_t * lqt_codec_info_copy_single(const lqt_codec_info_t * info)
   {
-  int i;
-  lqt_codec_info_t * ret = calloc(1, sizeof(lqt_codec_info_t));
-  
+  int i, len;
+  lqt_codec_info_t * ret = calloc(1, sizeof(*ret));
+//   fprintf(stderr, "lqt_codec_info_copy_single %s\n", info->name);
   ret->compatibility_flags = info->compatibility_flags;
     
   if(info->name)
@@ -311,21 +312,27 @@ copy_codec_info(const lqt_codec_info_t * info)
   ret->num_encoding_colormodels = info->num_encoding_colormodels;
   if(ret->num_encoding_colormodels)
     {
-    ret->encoding_colormodels = malloc(ret->num_encoding_colormodels *
-                                       sizeof(*ret->encoding_colormodels));
-    for(i = 0; i < ret->num_encoding_colormodels; i++)
-      ret->encoding_colormodels[i] = info->encoding_colormodels[i];
+    /* +1 to copy the terminating LQT_COLORMODEL_NODE */
+    len = (ret->num_encoding_colormodels + 1) * sizeof(*ret->encoding_colormodels);
+    ret->encoding_colormodels = malloc(len);
+    memcpy(ret->encoding_colormodels, info->encoding_colormodels, len);
     }
   
   ret->num_wav_ids = info->num_wav_ids;
   if(ret->num_wav_ids)
     {
-    ret->wav_ids = malloc(ret->num_wav_ids * sizeof(int));
-    for(i = 0; i < ret->num_wav_ids; i++)
-      ret->wav_ids[i] = info->wav_ids[i];
-    
+    len = ret->num_wav_ids * sizeof(*ret->wav_ids);
+    ret->wav_ids = malloc(len);
+    memcpy(ret->wav_ids, info->wav_ids, len);
+    }
+
+  ret->num_image_sizes = info->num_image_sizes;
+  if(ret->num_image_sizes)
+    {
+    len = ret->num_image_sizes * sizeof(*ret->image_sizes);
+    ret->image_sizes = malloc(len);
+    memcpy(ret->image_sizes, info->image_sizes, len);
     }
-  
   
   ret->num_encoding_parameters = info->num_encoding_parameters;
   
@@ -335,8 +342,8 @@ copy_codec_info(const lqt_codec_info_t * info)
       calloc(ret->num_encoding_parameters+1, sizeof(lqt_parameter_info_t));
 
     for(i = 0; i < ret->num_encoding_parameters; i++)
-      copy_parameter_info(&(ret->encoding_parameters[i]),
-                          &(info->encoding_parameters[i]));
+      copy_parameter_info(&ret->encoding_parameters[i],
+                          &info->encoding_parameters[i]);
     }
 
   ret->num_decoding_parameters = info->num_decoding_parameters;
@@ -346,9 +353,10 @@ copy_codec_info(const lqt_codec_info_t * info)
       calloc(ret->num_decoding_parameters, sizeof(lqt_parameter_info_t));
 
     for(i = 0; i < ret->num_decoding_parameters; i++)
-      copy_parameter_info(&(ret->decoding_parameters[i]),
-                          &(info->decoding_parameters[i]));
+      copy_parameter_info(&ret->decoding_parameters[i],
+                          &info->decoding_parameters[i]);
     }
+  ret->compression_id = info->compression_id;
   return ret;
   }
 
@@ -384,7 +392,7 @@ static lqt_codec_info_t * find_codec_by_filename(lqt_codec_info_t ** list,
         {
         tmp_ptr = ptr->next;
 
-        destroy_codec_info(ptr);
+        lqt_codec_info_destroy_single(ptr);
         ptr = tmp_ptr;
         }
       else
@@ -693,14 +701,14 @@ void lqt_registry_destroy()
   while(lqt_audio_codecs)
     {
     tmp = lqt_audio_codecs->next;
-    destroy_codec_info(lqt_audio_codecs);
+    lqt_codec_info_destroy_single(lqt_audio_codecs);
     lqt_audio_codecs = tmp;
     }
 
   while(lqt_video_codecs)
     {
     tmp = lqt_video_codecs->next;
-    destroy_codec_info(lqt_video_codecs);
+    lqt_codec_info_destroy_single(lqt_video_codecs);
     lqt_video_codecs = tmp;
     }
 
@@ -756,7 +764,7 @@ void lqt_registry_init()
     {
     tmp_file_codecs = file_codecs;
     file_codecs = file_codecs->next;
-    destroy_codec_info(tmp_file_codecs);
+    lqt_codec_info_destroy_single(tmp_file_codecs);
     do_write = 1;
     }
   
@@ -976,9 +984,11 @@ lqt_create_codec_info(const lqt_codec_info_static_t * template)
       }
 
     ret->encoding_colormodels =
-      malloc(ret->num_encoding_colormodels * sizeof(*ret->encoding_colormodels));
+      malloc((ret->num_encoding_colormodels+1) * sizeof(*ret->encoding_colormodels));
     for(i = 0; i < ret->num_encoding_colormodels; i++)
       ret->encoding_colormodels[i] = template->encoding_colormodels[i];
+    ret->encoding_colormodels[ret->num_encoding_colormodels] =
+      LQT_COLORMODEL_NONE;
     }
   
   /* Copy wav_ids */
@@ -999,10 +1009,29 @@ lqt_create_codec_info(const lqt_codec_info_static_t * template)
       ret->wav_ids[i] = template->wav_ids[i];
     }
 
+  /* Copy image_sizes */
+
+  ret->num_image_sizes = 0;
+
+  if(template->image_sizes)
+    {
+    while(template->image_sizes[ret->num_image_sizes].width)
+      ret->num_image_sizes++;
+
+    if(ret->num_image_sizes)
+      {
+      ret->image_sizes = malloc(ret->num_image_sizes *
+                                sizeof(*ret->image_sizes));
+      for(i = 0; i < ret->num_image_sizes; i++)
+        {
+        ret->image_sizes[i].width = template->image_sizes[i].width;
+        ret->image_sizes[i].height = template->image_sizes[i].height;
+        }
+      }
+    }
+  
+  /* Copy encoding parameters */
   
-  /* Copy encoding colormodels */
-    
-    
   if(template->encoding_parameters)
     {
     ret->num_encoding_parameters = 0;
@@ -1023,8 +1052,8 @@ lqt_create_codec_info(const lqt_codec_info_static_t * template)
     for(i = 0; i < ret->num_encoding_parameters; i++)
       {
       /* Copy parameter info */
-      create_parameter_info(&(ret->encoding_parameters[i]),
-                            &(template->encoding_parameters[i]));
+      create_parameter_info(&ret->encoding_parameters[i],
+                            &template->encoding_parameters[i]);
       }
     }
   else
@@ -1052,14 +1081,17 @@ lqt_create_codec_info(const lqt_codec_info_static_t * template)
     for(i = 0; i < ret->num_decoding_parameters; i++)
       {
       /* Copy parameter info */
-      create_parameter_info(&(ret->decoding_parameters[i]),
-                            &(template->decoding_parameters[i]));
+      create_parameter_info(&ret->decoding_parameters[i],
+                            &template->decoding_parameters[i]);
       }
     }
   else
     {
     ret->decoding_parameters = (lqt_parameter_info_t*)0;
     }
+
+  ret->compression_id = template->compression_id;
+  
   return ret;
   }
 
@@ -1138,6 +1170,10 @@ void lqt_dump_codec_info(const lqt_codec_info_t * info)
     lqt_dump("%s (0x%08x)\n", info->fourccs[i],
             LQT_STRING_2_FOURCC(info->fourccs[i]));
 
+  if(info->compression_id != LQT_COMPRESSION_NONE)
+    lqt_dump("Compression ID: %s\n",
+             lqt_compression_id_to_string(info->compression_id));
+  
   if(!info->num_encoding_parameters)
     {
     lqt_dump("No settable parameters for encoding\n");
@@ -1145,7 +1181,7 @@ void lqt_dump_codec_info(const lqt_codec_info_t * info)
   else
     {
     for(i = 0; i < info->num_encoding_parameters; i++)
-      dump_codec_parameter(&(info->encoding_parameters[i]));
+      dump_codec_parameter(&info->encoding_parameters[i]);
     }
 
   if(!info->num_encoding_parameters)
@@ -1155,7 +1191,7 @@ void lqt_dump_codec_info(const lqt_codec_info_t * info)
   else
     {
     for(i = 0; i < info->num_decoding_parameters; i++)
-      dump_codec_parameter(&(info->decoding_parameters[i]));
+      dump_codec_parameter(&info->decoding_parameters[i]);
     }
   lqt_dump("Module filename: %s\nIndex inside module: %d\n",
           info->module_filename, info->module_index);
@@ -1209,7 +1245,7 @@ lqt_codec_info_t ** lqt_find_audio_codec(char * fourcc, int encode)
   if(tmp_ptr)
     {
     ret = calloc(2, sizeof(lqt_codec_info_t*));
-    *ret = copy_codec_info(tmp_ptr);
+    *ret = lqt_codec_info_copy_single(tmp_ptr);
     }
   lqt_registry_unlock();
   return ret;
@@ -1251,7 +1287,7 @@ lqt_codec_info_t ** lqt_find_audio_codec_by_wav_id(int wav_id, int encode)
   if(tmp_ptr)
     {
     ret = calloc(2, sizeof(lqt_codec_info_t*));
-    *ret = copy_codec_info(tmp_ptr);
+    *ret = lqt_codec_info_copy_single(tmp_ptr);
     }
   lqt_registry_unlock();
   return ret;
@@ -1294,7 +1330,7 @@ lqt_codec_info_t ** lqt_find_video_codec(char * fourcc, int encode)
   if(tmp_ptr)
     {
     ret = calloc(2, sizeof(lqt_codec_info_t*));
-    *ret = copy_codec_info(tmp_ptr);
+    *ret = lqt_codec_info_copy_single(tmp_ptr);
     }
   lqt_registry_unlock();
 
@@ -1348,7 +1384,7 @@ lqt_codec_info_t ** lqt_query_registry(int audio, int video,
       if((encode && (info->direction != LQT_DIRECTION_DECODE)) ||
          (decode && (info->direction != LQT_DIRECTION_ENCODE)))
         {
-        ret[num_added] = copy_codec_info(info);
+        ret[num_added] = lqt_codec_info_copy_single(info);
         num_added++;
         }
       }
@@ -1361,7 +1397,7 @@ lqt_codec_info_t ** lqt_query_registry(int audio, int video,
       if((encode && (info->direction != LQT_DIRECTION_DECODE)) ||
          (decode && (info->direction != LQT_DIRECTION_ENCODE)))
         {
-        ret[num_added] = copy_codec_info(info);
+        ret[num_added] = lqt_codec_info_copy_single(info);
         num_added++;
         }
       }
@@ -1395,7 +1431,7 @@ lqt_codec_info_t ** lqt_find_audio_codec_by_name(const char * name)
     if(!strcmp(info->name, name))
       {
       ret = calloc(2, sizeof(lqt_codec_info_t*));
-      *ret = copy_codec_info(info);
+      *ret = lqt_codec_info_copy_single(info);
       break;
       }
     else
@@ -1428,7 +1464,7 @@ lqt_codec_info_t ** lqt_find_video_codec_by_name(const char * name)
     if(!strcmp(info->name, name))
       {
       ret = calloc(2, sizeof(lqt_codec_info_t*));
-      *ret = copy_codec_info(info);
+      *ret = lqt_codec_info_copy_single(info);
       break;
       }
     else
@@ -1448,13 +1484,13 @@ lqt_codec_info_t ** lqt_find_video_codec_by_name(const char * name)
 
 lqt_codec_info_t ** lqt_audio_codec_from_file(quicktime_t * file, int track)
   {
-  char * name = ((quicktime_codec_t*)(file->atracks[track].codec))->codec_name;
+  char * name = file->atracks[track].codec->info->name;
   return lqt_find_audio_codec_by_name(name);
   }
 
 lqt_codec_info_t ** lqt_video_codec_from_file(quicktime_t * file, int track)
   {
-  char * name = ((quicktime_codec_t*)(file->vtracks[track].codec))->codec_name;
+  char * name = file->vtracks[track].codec->info->name;
   return lqt_find_video_codec_by_name(name);
   }
 
@@ -1472,7 +1508,7 @@ void lqt_destroy_codec_info(lqt_codec_info_t ** info)
   
   while(*ptr)
     {
-    destroy_codec_info(*ptr);
+    lqt_codec_info_destroy_single(*ptr);
     ptr++;
     }
   free(info);
@@ -1633,8 +1669,8 @@ void lqt_restore_default_parameters(lqt_codec_info_t * codec_info,
       if(!strcmp(codec_info->encoding_parameters[i].name, 
                  info_from_module->encoding_parameters[i].name))
         {
-        copy_parameter_value(&(codec_info->encoding_parameters[i].val_default),
-                             &(info_from_module->encoding_parameters[i].val_default),
+        copy_parameter_value(&codec_info->encoding_parameters[i].val_default,
+                             &info_from_module->encoding_parameters[i].val_default,
                              codec_info->encoding_parameters[i].type);
 
         }
@@ -1651,8 +1687,8 @@ void lqt_restore_default_parameters(lqt_codec_info_t * codec_info,
       if(!strcmp(codec_info->decoding_parameters[i].name, 
                  info_from_module->decoding_parameters[i].name))
         {
-        copy_parameter_value(&(codec_info->decoding_parameters[i].val_default),
-                             &(info_from_module->decoding_parameters[i].val_default),
+        copy_parameter_value(&codec_info->decoding_parameters[i].val_default,
+                             &info_from_module->decoding_parameters[i].val_default,
                              codec_info->decoding_parameters[i].type);
 
         }
@@ -1662,7 +1698,7 @@ void lqt_restore_default_parameters(lqt_codec_info_t * codec_info,
   if(module)
     dlclose(module);
   if(info_from_module)
-    destroy_codec_info(info_from_module);
+    lqt_codec_info_destroy_single(info_from_module);
   
   }
 
