@@ -32,17 +32,10 @@
 
 #define LOG_DOMAIN "codecs"
 
-static int quicktime_delete_vcodec_stub(quicktime_video_map_t *vtrack)
+static int quicktime_delete_codec_stub(quicktime_codec_t *codec)
   {
   lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
-          "quicktime_delete_vcodec_stub called");
-  return 0;
-  }
-
-static int quicktime_delete_acodec_stub(quicktime_audio_map_t *atrack)
-  {
-  lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
-          "quicktime_delete_acodec_stub called");
+          "quicktime_delete_stub called");
   return 0;
   }
 
@@ -89,39 +82,74 @@ static int quicktime_flush_codec_stub(quicktime_t *file, int track)
   return 0;
   }
 
-
-static int quicktime_codec_defaults(quicktime_codec_t *codec)
+/*
+ *  Original quicktime4linux function changed for dynamic loading
+ */
+quicktime_codec_t * quicktime_load_codec(lqt_codec_info_t * info,
+                                         quicktime_audio_map_t * amap,
+                                         quicktime_video_map_t * vmap)
   {
-  codec->delete_vcodec = quicktime_delete_vcodec_stub;
-  codec->delete_acodec = quicktime_delete_acodec_stub;
+  quicktime_codec_t * codec;
+  lqt_init_codec_func_t init_codec;
+  lqt_init_codec_func_t (*get_codec)(int);
+
+  codec = calloc(1, sizeof(*codec));
+
+  /* Set stubs */
+  codec->delete_codec = quicktime_delete_codec_stub;
   codec->decode_video = quicktime_decode_video_stub;
   codec->encode_video = quicktime_encode_video_stub;
   codec->decode_audio = quicktime_decode_audio_stub;
   codec->encode_audio = quicktime_encode_audio_stub;
   codec->flush = quicktime_flush_codec_stub;
-  return 0;
-  }
+  
+  if(!info)
+    return codec;
+  
+  codec->info = lqt_codec_info_copy_single(info);
+  
+  lqt_log(NULL, LQT_LOG_DEBUG, LOG_DOMAIN,
+          "Loading module %s", info->module_filename);
 
-/*
- *  Original quicktime4linux function changed for dynamic loading
- */
+  /* dlopen the module */
+  codec->module = dlopen(info->module_filename, RTLD_NOW);
+  
+  if(!codec->module)
+    {
+    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN, "Loading module %s failed: %s",
+            info->module_filename, dlerror());
+    goto fail;
+    }
+
+  get_codec =
+    (lqt_init_codec_func_t(*)(int))dlsym(codec->module, "get_codec");
+  
+  if(!get_codec)
+    {
+    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
+            "Module %s contains no function get_codec",
+            info->module_filename);
+    goto fail;
+    }
+
+  init_codec = get_codec(info->module_index);
+  init_codec(codec, amap, vmap);
+  
+  return codec;
+
+  fail:
+  if(codec->module)
+    dlclose(codec->module);
+  free(codec);
+  return NULL;
+  }
 
 int quicktime_init_vcodec(quicktime_video_map_t *vtrack, int encode,
                           lqt_codec_info_t * codec_info)
   {
   lqt_codec_info_t ** codec_array = (lqt_codec_info_t**)0;
   
-  lqt_init_video_codec_func_t init_codec;
-  lqt_init_video_codec_func_t (*get_codec)(int);
-    
-  void * module = (void*)0;
-  
   char *compressor = vtrack->track->mdia.minf.stbl.stsd.table[0].format;
-
-  vtrack->codec = calloc(1, sizeof(quicktime_codec_t));
-  quicktime_codec_defaults((quicktime_codec_t*)vtrack->codec);
-
-  ((quicktime_codec_t*)vtrack->codec)->module = (void*)0;
   
   /* Try to find the codec */
 
@@ -131,62 +159,28 @@ int quicktime_init_vcodec(quicktime_video_map_t *vtrack, int encode,
   
     if(!codec_array)
       {
-      lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN, "Could not find video %s for fourcc %4s",
+      lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
+              "Could not find video %s for fourcc %4s",
               (encode ? "Encoder" : "Decoder"), compressor);
-      return -1;
       }
-    codec_info = *codec_array;
+    else
+      codec_info = *codec_array;
     }
+  
+  vtrack->codec = quicktime_load_codec(codec_info, NULL, vtrack);
 
-  vtrack->compatibility_flags = codec_info->compatibility_flags;
-  
-  lqt_log(NULL, LQT_LOG_DEBUG, LOG_DOMAIN,
-          "Loading module %s", codec_info->module_filename);
-  
-  /* dlopen the module */
-  module = dlopen(codec_info->module_filename, RTLD_NOW);
-  
-  if(!module)
+  if(!vtrack->codec)
     {
-    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN, "Loading module %s failed: %s",
-            codec_info->module_filename, dlerror());
+    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN, "Loading codec %s failed",
+            codec_info->name);
     
     if(codec_array)
       lqt_destroy_codec_info(codec_array);
 
     return -1;
+    
     }
-  
-  ((quicktime_codec_t*)vtrack->codec)->codec_name =
-    malloc(strlen(codec_info->name)+1);
-  strcpy(((quicktime_codec_t*)vtrack->codec)->codec_name, codec_info->name);
-  
-  /* Set the module */
-  
-  ((quicktime_codec_t*)vtrack->codec)->module = module;
-  
-  /* Get the codec finder for the module */
-  
-  get_codec =
-    (lqt_init_video_codec_func_t(*)(int))dlsym(module,
-                                               "get_video_codec");
-  
-  if(!get_codec)
-    {
-    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
-            "Module %s contains no function get_video_codec",
-            codec_info->module_filename);
-    if(codec_array)
-      lqt_destroy_codec_info(codec_array);
 
-    return -1;
-    }
-  
-  /* Obtain the initializer for the actual codec */
-  
-  init_codec = get_codec(codec_info->module_index);
-  
-  init_codec(vtrack);
   if(codec_array)
     lqt_destroy_codec_info(codec_array);
 
@@ -200,24 +194,14 @@ int quicktime_init_acodec(quicktime_audio_map_t *atrack, int encode,
                           lqt_codec_info_t * codec_info)
   {
   lqt_codec_info_t ** codec_array = (lqt_codec_info_t**)0;
-  lqt_init_audio_codec_func_t init_codec;
-  lqt_init_audio_codec_func_t (*get_codec)(int);
-    
-  void * module;
-
+  
   char *compressor = atrack->track->mdia.minf.stbl.stsd.table[0].format;
   int wav_id       = atrack->track->mdia.minf.stbl.stsd.table[0].compression_id;
-  atrack->codec = calloc(1, sizeof(quicktime_codec_t));
-  quicktime_codec_defaults((quicktime_codec_t*)atrack->codec);
-
-  ((quicktime_codec_t*)(atrack->codec))->module = (void*)0;
   
   /* Try to find the codec */
 
   if(!codec_info)
     {
-    
-
     if(compressor && (*compressor != '\0'))
       {
       codec_array = lqt_find_audio_codec(compressor, encode);
@@ -228,63 +212,20 @@ int quicktime_init_acodec(quicktime_audio_map_t *atrack, int encode,
       }
     if(!codec_array)
       {
-      lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN, "Could not find audio %s for fourcc %4s",
+      lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
+              "Could not find audio %s for fourcc %4s",
               (encode ? "Encoder" : "Decoder"), compressor);
-      return -1;
       }
-    codec_info = *codec_array;
+    else
+      codec_info = *codec_array;
     }
 
-  atrack->compatibility_flags = codec_info->compatibility_flags;
+  atrack->codec = quicktime_load_codec(codec_info, atrack, NULL);
   
-  lqt_log(NULL, LQT_LOG_DEBUG, LOG_DOMAIN,
-          "Loading module %s", codec_info->module_filename);
-  
-  /* dlopen the module */
-  module = dlopen(codec_info->module_filename, RTLD_NOW);
-  
-  if(!module)
-    {
-    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN, "Loading module %s failed: %s",
-            codec_info->module_filename, dlerror());
-    if(codec_array)
-      lqt_destroy_codec_info(codec_array);
-    return -1;
-    }
-
-  ((quicktime_codec_t*)atrack->codec)->codec_name = malloc(strlen(codec_info->name)+1);
-  strcpy(((quicktime_codec_t*)atrack->codec)->codec_name, codec_info->name);
-    
-  /* Set the module */
-  
-  ((quicktime_codec_t*)((quicktime_codec_t*)atrack->codec))->module = module;
-  
-  /* Get the codec finder for the module */
-  
-  get_codec =
-    (lqt_init_audio_codec_func_t(*)(int))dlsym(module,
-                                               "get_audio_codec");
-  
-  if(!get_codec)
-    {
-    lqt_log(NULL, LQT_LOG_WARNING, LOG_DOMAIN,
-            "Module %s contains no function get_audio_codec",
-            codec_info->module_filename);
-    if(codec_array)
-      lqt_destroy_codec_info(codec_array);
-    return -1;
-    }
-  
-  /* Obtain the initializer for the actual codec */
-
-  init_codec = get_codec(codec_info->module_index);
-  
-  init_codec(atrack);
-
   /* We set the wav ids from our info structure, so we don't have to do this
      in the plugin sources */
   
-  if(codec_info->num_wav_ids)
+  if(codec_info && codec_info->num_wav_ids)
     atrack->wav_id = codec_info->wav_ids[0];
   
   if(codec_array)
@@ -293,30 +234,18 @@ int quicktime_init_acodec(quicktime_audio_map_t *atrack, int encode,
   }
 
 
-int quicktime_delete_vcodec(quicktime_video_map_t *vtrack)
+int quicktime_delete_codec(quicktime_codec_t *codec)
   {
-  ((quicktime_codec_t*)vtrack->codec)->delete_vcodec(vtrack);
+  codec->delete_codec(codec);
   /* Close the module */
   
-  if(((quicktime_codec_t*)vtrack->codec)->module)
-    dlclose(((quicktime_codec_t*)vtrack->codec)->module);
-  if(((quicktime_codec_t*)vtrack->codec)->codec_name)
-    free(((quicktime_codec_t*)vtrack->codec)->codec_name);
-  free(vtrack->codec);
-  vtrack->codec = 0;
-  return 0;
-  }
+  if(codec->module)
+    dlclose(codec->module);
 
-int quicktime_delete_acodec(quicktime_audio_map_t *atrack)
-  {
-  ((quicktime_codec_t*)atrack->codec)->delete_acodec(atrack);
-  /* Close the module */
-  if(((quicktime_codec_t*)atrack->codec)->module)
-    dlclose(((quicktime_codec_t*)atrack->codec)->module);
-  if(((quicktime_codec_t*)atrack->codec)->codec_name)
-    free(((quicktime_codec_t*)atrack->codec)->codec_name);
-  free(atrack->codec);
-  atrack->codec = 0;
+  if(codec->info)
+    lqt_codec_info_destroy_single(codec->info);
+
+  free(codec);
   return 0;
   }
 
@@ -364,6 +293,20 @@ void lqt_update_frame_position(quicktime_video_map_t * track)
     track->stts_index++;
     track->stts_count = 0;
     }
+
+  if(track->track->mdia.minf.stbl.has_ctts)
+    {
+    track->ctts_count++;
+
+    if(track->ctts_count >=
+       track->track->mdia.minf.stbl.ctts.table[track->ctts_index].sample_count)
+      {
+      track->ctts_index++;
+      track->ctts_count = 0;
+      }
+    
+    }
+  
   track->current_position++;
   }
 
@@ -376,8 +319,8 @@ static void set_default_rowspan(quicktime_t *file, int track)
 
   lqt_get_default_rowspan(file->vtracks[track].io_cmodel,
                           quicktime_video_width(file, track),
-                          &(file->vtracks[track].io_row_span),
-                          &(file->vtracks[track].io_row_span_uv));
+                          &file->vtracks[track].io_row_span,
+                          &file->vtracks[track].io_row_span_uv);
   }
 
 /*
@@ -401,22 +344,22 @@ int lqt_decode_video(quicktime_t *file,
       {
       file->vtracks[track].temp_frame =
         lqt_rows_alloc(width, height, file->vtracks[track].stream_cmodel,
-                       &(file->vtracks[track].stream_row_span),
-                       &(file->vtracks[track].stream_row_span_uv));
+                       &file->vtracks[track].stream_row_span,
+                       &file->vtracks[track].stream_row_span_uv);
       }
     result =
-      ((quicktime_codec_t*)file->vtracks[track].codec)->decode_video(file,
-                                                                     file->vtracks[track].temp_frame,
-                                                                     track);
+      file->vtracks[track].codec->decode_video(file,
+                                               file->vtracks[track].temp_frame,
+                                               track);
     cmodel_transfer(row_pointers,                    //    unsigned char **output_rows, /* Leave NULL if non existent */
                     file->vtracks[track].temp_frame, //    unsigned char **input_rows,
                     0, //                                  int in_x,        /* Dimensions to capture from input frame */
                     0, //                                  int in_y, 
                     width, //                              int in_w, 
-                    height, //                             int in_h,
-                    width, //                              int out_w, 
-                    height, //                             int out_h,
-                    file->vtracks[track].stream_cmodel, // int in_colormodel, 
+                    height + file->vtracks[track].height_extension, // int in_h,
+                    width, //                              int out_w,
+                    height + file->vtracks[track].height_extension, // int out_h,
+                    file->vtracks[track].stream_cmodel, // int in_colormodel,
                     file->vtracks[track].io_cmodel,     // int out_colormodel,
                     file->vtracks[track].stream_row_span,   /* For planar use the luma rowspan */
                     file->vtracks[track].io_row_span,       /* For planar use the luma rowspan */
@@ -429,11 +372,11 @@ int lqt_decode_video(quicktime_t *file,
     file->vtracks[track].stream_row_span    = file->vtracks[track].io_row_span;
     file->vtracks[track].stream_row_span_uv = file->vtracks[track].io_row_span_uv;
           
-    result = ((quicktime_codec_t*)file->vtracks[track].codec)->decode_video(file, row_pointers, track);
+    result = file->vtracks[track].codec->decode_video(file, row_pointers, track);
           
     }
-        
-  lqt_update_frame_position(&(file->vtracks[track]));
+  
+  lqt_update_frame_position(&file->vtracks[track]);
   return result;
   }
 
@@ -474,13 +417,13 @@ long quicktime_decode_scaled(quicktime_t *file,
     {
     file->vtracks[track].temp_frame =
       lqt_rows_alloc(width, height, file->vtracks[track].stream_cmodel,
-                     &(file->vtracks[track].stream_row_span),
-                     &(file->vtracks[track].stream_row_span_uv));
+                     &file->vtracks[track].stream_row_span,
+                     &file->vtracks[track].stream_row_span_uv);
     }
   result =
-    ((quicktime_codec_t*)file->vtracks[track].codec)->decode_video(file,
-                                                                   file->vtracks[track].temp_frame,
-                                                                   track);
+    file->vtracks[track].codec->decode_video(file,
+                                             file->vtracks[track].temp_frame,
+                                             track);
   cmodel_transfer(row_pointers,                    //    unsigned char **output_rows, /* Leave NULL if non existent */
                   file->vtracks[track].temp_frame, //    unsigned char **input_rows,
                   in_x, //                               int in_x,        /* Dimensions to capture from input frame */
@@ -496,7 +439,7 @@ long quicktime_decode_scaled(quicktime_t *file,
                   file->vtracks[track].stream_row_span_uv, /* Chroma rowspan */
                   file->vtracks[track].io_row_span_uv      /* Chroma rowspan */);
         
-  lqt_update_frame_position(&(file->vtracks[track]));
+  lqt_update_frame_position(&file->vtracks[track]);
   return result;
   }
 
@@ -504,17 +447,17 @@ int lqt_set_video_pass(quicktime_t *file,
                        int pass, int total_passes, 
                        const char * stats_file, int track)
   {
-  if(((quicktime_codec_t*)file->vtracks[track].codec)->set_pass)
-    return ((quicktime_codec_t*)file->vtracks[track].codec)->set_pass(file,
-                                                                      track,
-                                                                      pass,
-                                                                      total_passes,
-                                                                      stats_file);
+  if(file->vtracks[track].codec->set_pass)
+    return file->vtracks[track].codec->set_pass(file,
+                                                track,
+                                                pass,
+                                                total_passes,
+                                                stats_file);
   else
     return 0;
   }
 
-static void start_encoding(quicktime_t *file)
+void lqt_start_encoding(quicktime_t *file)
   {
   int i;
   if(file->encoding_started)
@@ -532,13 +475,13 @@ static void start_encoding(quicktime_t *file)
   /* Trigger warnings if codecs are in the wrong container */
   for(i = 0; i < file->total_atracks; i++)
     {
-    if(!(file->atracks[i].compatibility_flags & file->file_type))
+    if(!(file->atracks[i].codec->info->compatibility_flags & file->file_type))
       lqt_log(file, LQT_LOG_WARNING, LOG_DOMAIN,
               "Audio codec and container are not known to be compatible. File might be playable by libquicktime only.");
     }
   for(i = 0; i < file->total_vtracks; i++)
     {
-    if(!(file->vtracks[i].compatibility_flags & file->file_type))
+    if(!(file->vtracks[i].codec->info->compatibility_flags & file->file_type))
       lqt_log(file, LQT_LOG_WARNING, LOG_DOMAIN,
               "Video codec and container are not known to be compatible. File might be playable by libquicktime only.");
     
@@ -555,7 +498,7 @@ static int do_encode_video(quicktime_t *file,
   int height;
   int width;
 
-  start_encoding(file);
+  lqt_start_encoding(file);
   
   set_default_rowspan(file, track);
   height = quicktime_video_height(file, track);
@@ -566,31 +509,32 @@ static int do_encode_video(quicktime_t *file,
     if(!file->vtracks[track].temp_frame)
       {
       file->vtracks[track].temp_frame =
-        lqt_rows_alloc(width, height, file->vtracks[track].stream_cmodel,
-                       &(file->vtracks[track].stream_row_span),
-                       &(file->vtracks[track].stream_row_span_uv));
+        lqt_rows_alloc(width, height + file->vtracks[track].height_extension,
+                       file->vtracks[track].stream_cmodel,
+                       &file->vtracks[track].stream_row_span,
+                       &file->vtracks[track].stream_row_span_uv);
       }
     cmodel_transfer(file->vtracks[track].temp_frame, //    unsigned char **output_rows, /* Leave NULL if non existent */
                     row_pointers,                    //    unsigned char **input_rows,
                     0, //                                  int in_x,        /* Dimensions to capture from input frame */
                     0, //                                  int in_y, 
                     width, //                              int in_w, 
-                    height, //                             int in_h,
+                    height + file->vtracks[track].height_extension, // int in_h,
                     width, //                              int out_w, 
-                    height, //                             int out_h,
+                    height + file->vtracks[track].height_extension, // int out_h,
                     file->vtracks[track].io_cmodel, // int in_colormodel, 
                     file->vtracks[track].stream_cmodel,     // int out_colormodel,
                     file->vtracks[track].io_row_span,   /* For planar use the luma rowspan */
                     file->vtracks[track].stream_row_span,       /* For planar use the luma rowspan */
                     file->vtracks[track].io_row_span_uv, /* Chroma rowspan */
                     file->vtracks[track].stream_row_span_uv      /* Chroma rowspan */);
-    result = ((quicktime_codec_t*)file->vtracks[track].codec)->encode_video(file, file->vtracks[track].temp_frame, track);
+    result = file->vtracks[track].codec->encode_video(file, file->vtracks[track].temp_frame, track);
     }
   else
     {
     file->vtracks[track].stream_row_span    = file->vtracks[track].io_row_span;
     file->vtracks[track].stream_row_span_uv = file->vtracks[track].io_row_span_uv;
-    result = ((quicktime_codec_t*)file->vtracks[track].codec)->encode_video(file, row_pointers, track);
+    result = file->vtracks[track].codec->encode_video(file, row_pointers, track);
     }
   return result;
   }
@@ -634,7 +578,7 @@ void lqt_write_frame_header(quicktime_t * file, int track,
   vtrack->picture_numbers[vtrack->cur_chunk] = pic_num;
   vtrack->keyframe = keyframe;
   
-  quicktime_write_chunk_header(file, trak, &vtrack->chunk_atom);
+  quicktime_write_chunk_header(file, trak);
   }
 
 
@@ -642,13 +586,10 @@ void lqt_write_frame_footer(quicktime_t * file, int track)
   {
   quicktime_video_map_t * vtrack = &file->vtracks[track];
   quicktime_trak_t * trak = vtrack->track;
-  
-  quicktime_write_chunk_footer(file, 
-                               trak, 
-                               vtrack->cur_chunk,
-                               &vtrack->chunk_atom, 
-                               1);
 
+  trak->chunk_samples = 1;
+  quicktime_write_chunk_footer(file, trak);
+  
   if(vtrack->keyframe)
     quicktime_insert_keyframe(file, vtrack->cur_chunk, track);
   vtrack->cur_chunk++;
@@ -664,9 +605,20 @@ void lqt_video_build_timestamp_tables(quicktime_t * file, int track)
   quicktime_stts_table_t * stts_tab;
   int64_t dts;
   int has_b_frames = 0;
+  
+  /* If all frames are keyframes, disable stss */
+  if(trak->mdia.minf.stbl.stss.total_entries == vtrack->cur_chunk)
+    trak->mdia.minf.stbl.stss.total_entries = 0;
+  
+  /* If we have no timestamp arrays (e.g. if stream was written compressed)
+     return here */
 
+  if(!vtrack->picture_numbers)
+    return;
+  
   stts = &trak->mdia.minf.stbl.stts;
   ctts = &trak->mdia.minf.stbl.ctts;
+  
 #if 0
   fprintf (stderr, "Build timestamp tables %ld frames %d\n",
            vtrack->cur_chunk, stts->default_duration);
@@ -718,11 +670,6 @@ void lqt_video_build_timestamp_tables(quicktime_t * file, int track)
 
   if(stts->table[vtrack->cur_chunk-1].sample_duration <= 0)
     stts->table[vtrack->cur_chunk-1].sample_duration = stts->default_duration;
-
-  /* If all frames are keyframes, disable stss */
-
-  if(trak->mdia.minf.stbl.stss.total_entries == vtrack->cur_chunk)
-    trak->mdia.minf.stbl.stss.total_entries = 0;
   
   /* If we have no B-frames, exit here */
   if(!has_b_frames)
@@ -790,7 +737,6 @@ int lqt_encode_video_d(quicktime_t *file,
 
   /* Must set valid timestamp for encoders */
   vtrack->timestamp = time;
-  
   lqt_video_append_timestamp(file, track, time, duration);
   
   result = do_encode_video(file, row_pointers, track);
@@ -854,10 +800,10 @@ int lqt_decode_audio_raw(quicktime_t *file,  void * output, long samples, int tr
   {
   int result;
   quicktime_audio_map_t * atrack;
-  atrack = &(file->atracks[track]);
-  result = ((quicktime_codec_t*)(atrack->codec))->decode_audio(file, output, 
-                                                               samples,
-                                                               track);
+  atrack = &file->atracks[track];
+  result = atrack->codec->decode_audio(file, output, 
+                                       samples,
+                                       track);
 
   file->atracks[track].current_position += samples;
   return result;
@@ -869,10 +815,10 @@ int lqt_encode_audio_raw(quicktime_t *file,  void * input, long samples, int tra
   quicktime_audio_map_t * atrack;
   if(!samples)
     return 0;
-  atrack = &(file->atracks[track]);
-  start_encoding(file);
+  atrack = &file->atracks[track];
+  lqt_start_encoding(file);
   file->atracks[track].current_position += samples;
-  result = ((quicktime_codec_t*)(atrack->codec))->encode_audio(file, input, 
+  result = atrack->codec->encode_audio(file, input, 
                                                                samples,
                                                                track);
   if(file->io_error)
@@ -891,10 +837,10 @@ static int decode_audio_old(quicktime_t *file,
   {
   int result;
   quicktime_audio_map_t * atrack;
-  atrack = &(file->atracks[track]);
+  atrack = &file->atracks[track];
 
   if(atrack->sample_format == LQT_SAMPLE_UNDEFINED)
-    ((quicktime_codec_t*)(atrack->codec))->decode_audio(file, (void*)0, 
+    atrack->codec->decode_audio(file, (void*)0, 
                                                         0, track);
   
   
@@ -911,7 +857,7 @@ static int decode_audio_old(quicktime_t *file,
   
   /* Decode */
 
-  result = ((quicktime_codec_t*)(atrack->codec))->decode_audio(file, atrack->sample_buffer, 
+  result = atrack->codec->decode_audio(file, atrack->sample_buffer, 
                                                                samples,
                                                                track);
   
@@ -1053,14 +999,14 @@ static int encode_audio_old(quicktime_t *file,
                             int track)
   {
   quicktime_audio_map_t * atrack;
-  atrack = &(file->atracks[track]);
-  start_encoding(file);
+  atrack = &file->atracks[track];
+  lqt_start_encoding(file);
   
   if(!samples)
     return 0;
   
   if(atrack->sample_format == LQT_SAMPLE_UNDEFINED)
-    ((quicktime_codec_t*)(atrack->codec))->encode_audio(file, (void*)0, 
+    atrack->codec->encode_audio(file, (void*)0, 
                                                         0, track);
 
   
@@ -1084,7 +1030,7 @@ static int encode_audio_old(quicktime_t *file,
 
   file->atracks[track].current_position += samples;
   
-  return ((quicktime_codec_t*)(atrack->codec))->encode_audio(file, atrack->sample_buffer,
+  return atrack->codec->encode_audio(file, atrack->sample_buffer,
                                                              samples, track);
   
   }
@@ -1126,14 +1072,14 @@ int quicktime_writes_cmodel(quicktime_t *file,
 
 static int quicktime_flush_acodec(quicktime_t *file, int track)
   {
-  ((quicktime_codec_t*)file->atracks[track].codec)->flush(file, track);
+  file->atracks[track].codec->flush(file, track);
   return 0;
   }
 
 static void quicktime_flush_vcodec(quicktime_t *file, int track)
   {
   
-  while(((quicktime_codec_t*)file->vtracks[track].codec)->flush(file, track))
+  while(file->vtracks[track].codec->flush(file, track))
     ;
   }
 
