@@ -297,128 +297,88 @@ int lqt_get_decoder_colormodel(quicktime_t * file, int track)
   return file->vtracks[track].stream_cmodel;
   }
 
-static int
-lqt_get_best_colormodel_decode(quicktime_t * file, int track, int * supported)
+int
+lqt_get_best_target_colormodel(int source, int const* target_options)
   {
+  int conversion_price = 0, best_conversion_price = 10;
   int ret = LQT_COLORMODEL_NONE;
+  int i;
 
-  int index;
+  if (!target_options) {
+    /* Undocumented behavior, but from inside libquicktime we rely on it. */
+    return ret;
+  }
 
-  int best_conversion_price;
-  int conversion_price;
-  
-  int decoder_colormodel = LQT_COLORMODEL_NONE;
-
-  decoder_colormodel = lqt_get_decoder_colormodel(file, track);
-  
-  /* Check, if the decoder colormodel is directly supported */
-
-  if(decoder_colormodel != LQT_COLORMODEL_NONE)
+  for(i = 0; target_options[i] != LQT_COLORMODEL_NONE; ++i)
     {
-    index = 0;
-    while(supported[index] != LQT_COLORMODEL_NONE)
+    if (target_options[i] == source)
+      return source;
+
+    if(lqt_colormodel_has_conversion(source, target_options[i]))
       {
-      if(decoder_colormodel == supported[index])
+      conversion_price = get_conversion_price(source, target_options[i]);
+
+      if(conversion_price < best_conversion_price)
         {
-        ret = supported[index];
-        break;
+        best_conversion_price = conversion_price;
+        ret = target_options[i];
         }
-      else
-        index++;
       }
     }
-  else
-    ret = BC_RGB888;
-  
 
-  if(ret == LQT_COLORMODEL_NONE)
-    {
-    index = 0;
-
-    best_conversion_price = 10;
-
-    while(supported[index] != LQT_COLORMODEL_NONE)
-      {
-      if(quicktime_reads_cmodel(file, supported[index], track))
-        {
-        conversion_price
-          = get_conversion_price(decoder_colormodel, supported[index]);
-        if(conversion_price < best_conversion_price)
-          {
-          best_conversion_price = conversion_price;
-          ret = supported[index];
-          }
-        }
-      index++;
-      }
-    }
-  if(ret == LQT_COLORMODEL_NONE)
-    ret = BC_RGB888;
   return ret;
   }
 
-static int
-lqt_get_best_colormodel_encode(quicktime_t * file, int track,
-                               int * supported)
+int
+lqt_get_best_source_colormodel(int const* source_options, int target)
   {
-  int index_supported;
-
   int conversion_price = 0, best_conversion_price = 10;
   int ret = LQT_COLORMODEL_NONE;
-  
-  index_supported = 0;
+  int i;
 
+  if (!source_options) {
+    /* Undocumented behavior, but from inside libquicktime we rely on it. */
+    return ret;
+  }
 
-  while(supported[index_supported] != LQT_COLORMODEL_NONE)
+  for(i = 0; source_options[i] != LQT_COLORMODEL_NONE; ++i)
     {
-    if(file->vtracks[track].stream_cmodel == supported[index_supported])
-      {
-      ret = file->vtracks[track].stream_cmodel;
-      break;
-      }
-    index_supported++;
-    }
-  
-  if(ret == LQT_COLORMODEL_NONE)
-    {
-    index_supported = 0;
+    if(source_options[i] == target)
+      return target;
 
-    best_conversion_price = 10;
-    
-    while(supported[index_supported] != LQT_COLORMODEL_NONE)
+    if(lqt_colormodel_has_conversion(source_options[i], target))
       {
-      if(quicktime_writes_cmodel(file, supported[index_supported], track))
-        {
-        conversion_price =
-          get_conversion_price(file->vtracks[track].stream_cmodel,
-                               supported[index_supported]);
+      conversion_price = get_conversion_price(source_options[i], target);
         
-        if(conversion_price < best_conversion_price) 
-          {
-          best_conversion_price = conversion_price;
-          ret = supported[index_supported];
-          }
+      if(conversion_price < best_conversion_price)
+        {
+        best_conversion_price = conversion_price;
+        ret = source_options[i];
         }
-      index_supported++;
       }
     }
   
-  if(ret == LQT_COLORMODEL_NONE)
-    {
-    ret = BC_RGB888;
-    }
   return ret;
   }
 
 int lqt_get_best_colormodel(quicktime_t * file, int track,
                             int * supported)
   {
+  int ret;
   if((track >= file->total_vtracks) || (track < 0))
     return LQT_COLORMODEL_NONE;
   if(file->wr)
-    return lqt_get_best_colormodel_encode(file, track, supported);
+    ret = lqt_get_best_source_colormodel(supported, file->vtracks[track].stream_cmodel);
   else
-    return lqt_get_best_colormodel_decode(file, track, supported);
+    ret = lqt_get_best_target_colormodel(file->vtracks[track].stream_cmodel, supported);
+
+  if(ret == LQT_COLORMODEL_NONE)
+    {
+    /* Backwards compatibility. */
+    ret = BC_RGB888;
+    }
+
+  return ret;
   }
 
 static const int num_colormodels =
@@ -457,7 +417,7 @@ int lqt_get_colormodel(int index)
   return colormodel_table[index].colormodel;
   }
 
-static int get_bytes_per_line(int colormodel, int width)
+static int get_bytes_per_element(int colormodel)
   {
   switch(colormodel)
     {
@@ -466,27 +426,32 @@ static int get_bytes_per_line(int colormodel, int width)
     case BC_YUV422:
     case BC_YUV422P16:
     case BC_YUV444P16:
-      return width * 2;
+      return 2;
       break;
     case BC_BGR888:
     case BC_RGB888:
-      return width * 3;
+      return 3;
       break;
     case BC_BGR8888:
     case BC_RGBA8888:
     case BC_YUVA8888:
-      return width * 4;
+      return 4;
       break;
-      
     case BC_RGB161616:
-      return width * 6;
+      return 6;
       break;
     case BC_RGBA16161616:
-      return width * 8;
+      return 8;
       break;
     default:
-      return width;
+      return 1;
     }
+  
+  }
+
+static int get_bytes_per_line(int colormodel, int width)
+  {
+  return get_bytes_per_element(colormodel) * width;
   }
 
 /* Allocate and free row_pointers for use with libquicktime */
@@ -517,8 +482,8 @@ uint8_t ** lqt_rows_alloc(int width, int height, int colormodel, int * rowspan,
 
     video_buffer    = malloc(3 * sizeof(unsigned char*));
     video_buffer[0] = malloc(y_size + 2 * uv_size);
-    video_buffer[1] = &(video_buffer[0][y_size]);
-    video_buffer[2] = &(video_buffer[0][y_size+uv_size]);
+    video_buffer[1] = &video_buffer[0][y_size];
+    video_buffer[2] = &video_buffer[0][y_size+uv_size];
     }
   else
     {
@@ -529,7 +494,7 @@ uint8_t ** lqt_rows_alloc(int width, int height, int colormodel, int * rowspan,
         
     video_buffer[0] = malloc(height * bytes_per_line);
     for(i = 1; i < height; i++)
-      video_buffer[i] = &(video_buffer[0][i*bytes_per_line]);
+      video_buffer[i] = &video_buffer[0][i*bytes_per_line];
     
     }
   return video_buffer;
@@ -559,41 +524,281 @@ void lqt_rows_free(uint8_t ** rows)
 void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height, int in_rowspan,
                    int in_rowspan_uv, int out_rowspan, int out_rowspan_uv, int colormodel)
   {
+  lqt_rows_copy_sub(out_rows, in_rows,
+                    width, height, in_rowspan,
+                    in_rowspan_uv, out_rowspan,
+                    out_rowspan_uv, colormodel, 0, 0, 0, 0);
+  }
+
+void lqt_rows_clear(uint8_t **rows,
+                    int width, int height, int rowspan, int rowspan_uv, int colormodel)
+  {
+  int i, j, bytes_per_element, bytes_per_line;
+  uint8_t * ptr;
+  uint16_t * ptr_16;
+  uint8_t * ptr_start;
+  int sub_h, sub_v;
+
+  bytes_per_element = get_bytes_per_element(colormodel);
+  bytes_per_line = bytes_per_element * width;
+  switch(colormodel)
+    {
+    case BC_RGB565:
+    case BC_BGR565:
+    case BC_BGR888:
+    case BC_BGR8888:
+    case BC_RGB888:
+    case BC_RGB161616:
+    case BC_RGBA8888:
+    case BC_RGBA16161616:
+      if(rows[1])
+        {
+        for(i = 0; i < height; i++)
+          memset(rows[i], 0, bytes_per_line);
+        }
+      else
+        {
+        ptr = rows[0];
+        for(i = 0; i < height; i++)
+          {
+          memset(ptr, 0, bytes_per_line);
+          ptr += rowspan;
+          }
+        }
+      break;
+    case BC_YUVA8888:
+      if(rows[1])
+        {
+        for(i = 0; i < height; i++)
+          {
+          ptr = rows[i];
+          for(j = 0; j < width; j++)
+            {
+            ptr[0] = 0x10;
+            ptr[1] = 0x80;
+            ptr[2] = 0x80;
+            ptr[3] = 0x00;
+            ptr += 4;
+            }
+          }
+        }
+      else
+        {
+        ptr_start = rows[0];
+        for(i = 0; i < height; i++)
+          {
+          ptr = ptr_start;
+
+          for(j = 0; j < width; j++)
+            {
+            ptr[0] = 0x10;
+            ptr[1] = 0x80;
+            ptr[2] = 0x80;
+            ptr[3] = 0x00;
+            ptr += 4;
+            }
+          
+          ptr_start += rowspan;
+          }
+        }
+      break;
+    case BC_YUV422:
+      if(rows[1])
+        {
+        for(i = 0; i < height; i++)
+          {
+          ptr = rows[i];
+          for(j = 0; j < width; j++)
+            {
+            ptr[0] = 0x10;
+            ptr[1] = 0x80;
+            ptr += 2;
+            }
+          }
+        }
+      else
+        {
+        ptr_start = rows[0];
+        for(i = 0; i < height; i++)
+          {
+          ptr = ptr_start;
+          for(j = 0; j < width; j++)
+            {
+            ptr[0] = 0x10;
+            ptr[1] = 0x80;
+            ptr += 2;
+            }
+          ptr_start += rowspan;
+          }
+        }
+      break;
+    case BC_YUV420P:
+    case BC_YUV422P:
+    case BC_YUV444P:
+    case BC_YUV411P:
+      lqt_colormodel_get_chroma_sub(colormodel, &sub_h, &sub_v);
+      /* Y */
+      ptr = rows[0];
+      for(i = 0; i < height; i++)
+        {
+        memset(ptr, 0x10, width);
+        ptr += rowspan;
+        }
+
+      width /= sub_h;
+      height /= sub_v;
+      
+      /* U */
+      ptr = rows[1];
+      for(i = 0; i < height; i++)
+        {
+        memset(ptr, 0x80, width);
+        ptr += rowspan_uv;
+        }
+
+      /* V */
+      ptr = rows[2];
+      for(i = 0; i < height; i++)
+        {
+        memset(ptr, 0x80, width);
+        ptr += rowspan_uv;
+        }
+      
+      break;
+    case BC_YUVJ420P:
+    case BC_YUVJ422P:
+    case BC_YUVJ444P:
+      lqt_colormodel_get_chroma_sub(colormodel, &sub_h, &sub_v);
+      /* Y */
+      ptr = rows[0];
+      for(i = 0; i < height; i++)
+        {
+        memset(ptr, 0x00, width);
+        ptr += rowspan;
+        }
+
+      width /= sub_h;
+      height /= sub_v;
+      
+      /* U */
+      ptr = rows[1];
+      for(i = 0; i < height; i++)
+        {
+        memset(ptr, 0x80, width);
+        ptr += rowspan_uv;
+        }
+
+      /* V */
+      ptr = rows[2];
+      for(i = 0; i < height; i++)
+        {
+        memset(ptr, 0x80, width);
+        ptr += rowspan_uv;
+        }
+      break;
+    case BC_YUV422P16:
+    case BC_YUV444P16:
+
+      lqt_colormodel_get_chroma_sub(colormodel, &sub_h, &sub_v);
+
+      /* Y */
+      ptr_start = rows[0];
+      for(i = 0; i < height; i++)
+        {
+        ptr_16 = (uint16_t*)ptr_start;
+        for(j = 0; j < width; j++)
+          {
+          *ptr_16 = 0x1000;
+          ptr_16++;
+          }
+        ptr_start += rowspan;
+        }
+
+      width /= sub_h;
+      height /= sub_v; // Unneccesary actually
+
+      /* U */
+      ptr_start = rows[1];
+      for(i = 0; i < height; i++)
+        {
+        ptr_16 = (uint16_t*)ptr_start;
+        for(j = 0; j < width; j++)
+          {
+          *ptr_16 = 0x1000;
+          ptr_16++;
+          }
+        ptr_start += rowspan;
+        }
+      
+      /* V */
+      ptr_start = rows[2];
+      for(i = 0; i < height; i++)
+        {
+        ptr_16 = (uint16_t*)ptr_start;
+        for(j = 0; j < width; j++)
+          {
+          *ptr_16 = 0x1000;
+          ptr_16++;
+          }
+        ptr_start += rowspan;
+        }
+      
+      
+      break;
+    }
+  }
+
+void lqt_rows_copy_sub(uint8_t **out_rows, uint8_t **in_rows,
+                       int width, int height, int in_rowspan,
+                       int in_rowspan_uv, int out_rowspan,
+                       int out_rowspan_uv, int colormodel, int src_x, int src_y, int dst_x, int dst_y)
+  {
   uint8_t * src_ptr, *dst_ptr;
   int i;
   int sub_h = 0, sub_v = 0;
-
-  int bytes_per_line;
+  
+  int bytes_per_line, bytes_per_element;
+  
+  bytes_per_line = get_bytes_per_line(colormodel, width);
+  bytes_per_element = get_bytes_per_element(colormodel);
+  
   if(lqt_colormodel_is_planar(colormodel))
     {
     lqt_colormodel_get_chroma_sub(colormodel, &sub_h, &sub_v);
 
+    /* Align */
+    src_x /= sub_h;
+    src_x *= sub_h;
+
+    src_y /= sub_v;
+    src_y *= sub_v;
+    
     /* Luma plane */
-        
-    src_ptr = in_rows[0];
-    dst_ptr = out_rows[0];
+    
+    src_ptr = in_rows[0] + src_x * bytes_per_element + src_y * in_rowspan;
+    dst_ptr = out_rows[0] + src_x * bytes_per_element + dst_y * out_rowspan;
     for(i = 0; i < height; i++)
       {
-      memcpy(dst_ptr, src_ptr, width);
+      memcpy(dst_ptr, src_ptr, bytes_per_line);
       src_ptr += in_rowspan;
       dst_ptr += out_rowspan;
       }
     /* Chroma planes */
 
-    src_ptr = in_rows[1];
-    dst_ptr = out_rows[1];
+    src_ptr = in_rows[1] + src_x/sub_h * bytes_per_element + src_y * in_rowspan_uv;
+    dst_ptr = out_rows[1] + dst_x/sub_h * bytes_per_element + dst_y * out_rowspan_uv;
     for(i = 0; i < (height + sub_v - 1)/sub_v; i++)
       {
-      memcpy(dst_ptr, src_ptr, (width + sub_h - 1)/sub_h);
+      memcpy(dst_ptr, src_ptr, (bytes_per_line + sub_h - 1)/sub_h);
       src_ptr += in_rowspan_uv;
       dst_ptr += out_rowspan_uv;
       }
-
-    src_ptr = in_rows[2];
-    dst_ptr = out_rows[2];
+    
+    src_ptr = in_rows[2] + src_x/sub_h * bytes_per_element + src_y * in_rowspan_uv;
+    dst_ptr = out_rows[2] + dst_x/sub_h * bytes_per_element + dst_y * out_rowspan_uv;
     for(i = 0; i < (height + sub_v - 1)/sub_v; i++)
       {
-      memcpy(dst_ptr, src_ptr, (width + sub_h - 1)/sub_h);
+      memcpy(dst_ptr, src_ptr, (bytes_per_line + sub_h - 1)/sub_h);
       src_ptr += in_rowspan_uv;
       dst_ptr += out_rowspan_uv;
       }
@@ -605,37 +810,36 @@ void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height,
        We test rows[1] to check this and handle all 4 combinations
        separately */
     
-    bytes_per_line = get_bytes_per_line(colormodel, width);
-    
     if(in_rows[1] && out_rows[1])
       {
       for(i = 0; i < height; i++)
-        memcpy(out_rows[i], in_rows[i], bytes_per_line);
+        memcpy(out_rows[i + dst_y] + dst_x * bytes_per_element,
+               in_rows[i + src_y] + src_x * bytes_per_element, bytes_per_line);
       }
     else if(in_rows[1])
       {
-      dst_ptr = out_rows[0];
+      dst_ptr = out_rows[0] + dst_y * bytes_per_line + dst_x * bytes_per_element;
       
       for(i = 0; i < height; i++)
         {
-        memcpy(dst_ptr, in_rows[i], bytes_per_line);
+        memcpy(dst_ptr, in_rows[i + src_y] + src_x * bytes_per_element, bytes_per_line);
         dst_ptr += out_rowspan;
         }
       }
     else if(out_rows[1])
       {
-      src_ptr = in_rows[0];
+      src_ptr = in_rows[0] + src_y * bytes_per_line + src_x * bytes_per_element;
       
       for(i = 0; i < height; i++)
         {
-        memcpy(out_rows[i], src_ptr, bytes_per_line);
+        memcpy(out_rows[i + dst_y] + dst_x * bytes_per_element, src_ptr, bytes_per_line);
         src_ptr += in_rowspan;
         }
       }
     else
       {
-      src_ptr = in_rows[0];
-      dst_ptr = out_rows[0];
+      src_ptr = in_rows[0] + src_y * bytes_per_line + src_x * bytes_per_element;
+      dst_ptr = out_rows[0] + dst_y * bytes_per_line + dst_x * bytes_per_element;
       
       for(i = 0; i < height; i++)
         {
@@ -647,6 +851,7 @@ void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height,
     }
   }
 
+
 // for i in BC_RGB565 BC_BGR565 BC_BGR888 BC_BGR8888 BC_RGB888 BC_RGBA8888 BC_RGB161616 BC_RGBA16161616 BC_YUVA8888 BC_YUV422 BC_YUV420P BC_YUV422P BC_YUV444P BC_YUV411P BC_YUVJ420P BC_YUVJ422P BC_YUVJ444P BC_YUV422P16 BC_YUV444P16; do for j in BC_RGB565 BC_BGR565 BC_BGR888 BC_BGR8888 BC_RGB888 BC_RGBA8888 BC_RGB161616 BC_RGBA16161616 BC_YUVA8888 BC_YUV422 BC_YUV420P BC_YUV422P BC_YUV444P BC_YUV411P BC_YUVJ420P BC_YUVJ422P BC_YUVJ444P BC_YUV422P16 BC_YUV444P16; do echo $i"_to_"$j.png; gthumb $i"_to_"$j.png; done; done
 
 int lqt_colormodel_has_conversion(int in_cmodel, int out_cmodel)
