@@ -139,7 +139,7 @@ int quicktime_make_streamable(char *in_path, char *out_path)
         return 1;
         }
 
-      quicktime_shift_offsets(&(old_file->moov), moov_length+8);
+      quicktime_shift_offsets(&old_file->moov, moov_length+8);
 
       /* open the output file */
 			
@@ -159,10 +159,10 @@ int quicktime_make_streamable(char *in_path, char *out_path)
         new_file.presave_buffer = calloc(1, QUICKTIME_PRESAVE);
         new_file.file_type = old_file->file_type;
         if(old_file->has_ftyp)
-          quicktime_write_ftyp(&new_file, &(old_file->ftyp));
+          quicktime_write_ftyp(&new_file, &old_file->ftyp);
                         
         moov_start = quicktime_position(&new_file);
-        quicktime_write_moov(&new_file, &(old_file->moov));
+        quicktime_write_moov(&new_file, &old_file->moov);
 
         if(moov_length !=
            quicktime_position(&new_file) - moov_start)
@@ -178,7 +178,7 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 
         quicktime_atom_write_header64(&new_file, 
                                          
-                                      &(new_file.mdat.atom), 
+                                      &new_file.mdat.atom, 
                                       "mdat");
 				
         quicktime_set_position(old_file, mdat_start);
@@ -212,7 +212,7 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 
         quicktime_atom_write_footer(&new_file, 
                                          
-                                    &(new_file.mdat.atom));
+                                    &new_file.mdat.atom);
 			
 				
         if(new_file.presave_size)
@@ -244,14 +244,14 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 void lqt_set_audio_parameter(quicktime_t *file,int stream, const char *key,
                              const void *value)
   {
-  quicktime_codec_t *codec = (quicktime_codec_t*)file->atracks[stream].codec;
+  quicktime_codec_t *codec = file->atracks[stream].codec;
   if(codec->set_parameter) codec->set_parameter(file, stream, key, value);
   }
 
 void lqt_set_video_parameter(quicktime_t *file,int stream, const char *key,
                              const void *value)
   {
-  quicktime_codec_t *codec = (quicktime_codec_t*)file->vtracks[stream].codec;
+  quicktime_codec_t *codec = file->vtracks[stream].codec;
   if(codec->set_parameter) codec->set_parameter(file, stream, key, value);
   }
 
@@ -280,19 +280,19 @@ void quicktime_set_jpeg(quicktime_t *file, int quality, int use_float)
 
 void quicktime_set_copyright(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.copyright),
-                            &(file->moov.udta.copyright_len), string);
+  quicktime_set_udta_string(&file->moov.udta.copyright,
+                            &file->moov.udta.copyright_len, string);
   }
 
 void quicktime_set_name(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.name),
-                            &(file->moov.udta.name_len), string);
+  quicktime_set_udta_string(&file->moov.udta.name,
+                            &file->moov.udta.name_len, string);
   }
 
 void quicktime_set_info(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.info), &(file->moov.udta.info_len), string);
+  quicktime_set_udta_string(&file->moov.udta.info, &file->moov.udta.info_len, string);
   }
 
 char* quicktime_get_copyright(quicktime_t *file)
@@ -314,38 +314,38 @@ char* quicktime_get_info(quicktime_t *file)
 
 void lqt_set_album(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.album),
-                            &(file->moov.udta.album_len), string);
+  quicktime_set_udta_string(&file->moov.udta.album,
+                            &file->moov.udta.album_len, string);
   }
 
 void lqt_set_artist(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.artist),
-                            &(file->moov.udta.artist_len), string);
+  quicktime_set_udta_string(&file->moov.udta.artist,
+                            &file->moov.udta.artist_len, string);
   }
 
 void lqt_set_genre(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.genre),
-                            &(file->moov.udta.genre_len), string);
+  quicktime_set_udta_string(&file->moov.udta.genre,
+                            &file->moov.udta.genre_len, string);
   }
 
 void lqt_set_track(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.track),
-                            &(file->moov.udta.track_len), string);
+  quicktime_set_udta_string(&file->moov.udta.track,
+                            &file->moov.udta.track_len, string);
   }
 
 void lqt_set_comment(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.comment),
-                            &(file->moov.udta.comment_len), string);
+  quicktime_set_udta_string(&file->moov.udta.comment,
+                            &file->moov.udta.comment_len, string);
   }
 
 void lqt_set_author(quicktime_t *file, char *string)
   {
-  quicktime_set_udta_string(&(file->moov.udta.author),
-                            &(file->moov.udta.author_len), string);
+  quicktime_set_udta_string(&file->moov.udta.author,
+                            &file->moov.udta.author_len, string);
   }
 
 void lqt_set_creation_time(quicktime_t *file, unsigned long time)
@@ -405,48 +405,69 @@ int quicktime_audio_tracks(quicktime_t *file)
   quicktime_minf_t *minf;
   for(i = 0; i < file->moov.total_tracks; i++)
     {
-    minf = &(file->moov.trak[i]->mdia.minf);
+    minf = &file->moov.trak[i]->mdia.minf;
     if(minf->is_audio)
       result++;
     }
   return result;
   }
 
-int lqt_add_audio_track(quicktime_t *file,
-                        int channels, long sample_rate, int bits,
-                        lqt_codec_info_t * codec_info)
+int lqt_set_audio_codec(quicktime_t *file, int track,
+                        lqt_codec_info_t * info)
+  {
+  quicktime_stsd_t * stsd;
+  
+  stsd = &file->atracks[track].track->mdia.minf.stbl.stsd;
+  
+  quicktime_stsd_set_audio_codec(stsd, info->fourccs[0]);
+  
+  quicktime_init_audio_map(file, &file->atracks[track],
+                           file->wr,
+                           info);
+  lqt_set_default_audio_parameters(file, track);
+  return 0;
+  }
+
+int lqt_add_audio_track_internal(quicktime_t *file,
+                                 int channels, long sample_rate, int bits,
+                                 lqt_codec_info_t * codec_info,
+                                 const lqt_compression_info_t * ci)
   {
   quicktime_trak_t *trak;
-  char * compressor = codec_info->fourccs[0];
-
-  /* Fake the bits parameter for some formats. */
-  if(quicktime_match_32(compressor, QUICKTIME_ULAW) ||
-     quicktime_match_32(compressor, QUICKTIME_IMA4))
-    bits = 16;
-  else if(quicktime_match_32(compressor, QUICKTIME_RAW))
-    bits = 8;
-
+  char * compressor = codec_info ? codec_info->fourccs[0] : NULL;
+  
   file->atracks = realloc(file->atracks,
-                          (file->total_atracks+1)*sizeof(quicktime_audio_map_t));
+                          (file->total_atracks+1)*sizeof(*file->atracks));
 
-  memset(&(file->atracks[file->total_atracks]), 0, sizeof(quicktime_audio_map_t));
+  memset(&file->atracks[file->total_atracks], 0, sizeof(*file->atracks));
+  
+  if(ci)
+    lqt_compression_info_copy(&file->atracks[file->total_atracks].ci, ci);
   
   trak = quicktime_add_track(file);
   quicktime_trak_init_audio(file, trak, channels,
                             sample_rate, bits, compressor);
-  
-  quicktime_init_audio_map(file, &(file->atracks[file->total_atracks]),
-                           trak, file->wr,
-                           codec_info);
   file->atracks[file->total_atracks].track = trak;
-  file->atracks[file->total_atracks].channels = channels;
-  file->atracks[file->total_atracks].current_position = 0;
-  file->atracks[file->total_atracks].cur_chunk = 0;
-  lqt_set_default_audio_parameters(file, file->total_atracks);
+  
   file->total_atracks++;
+  
+  if(codec_info)
+    return lqt_set_audio_codec(file, file->total_atracks-1,
+                               codec_info);
   return 0;
   }
 
+int lqt_add_audio_track(quicktime_t *file,
+                        int channels, long sample_rate, int bits,
+                        lqt_codec_info_t * codec_info)
+  {
+  return lqt_add_audio_track_internal(file,
+                                      channels,
+                                      sample_rate,
+                                      bits,
+                                      codec_info, NULL);
+  }
+
 int lqt_set_audio(quicktime_t *file, int channels,
                   long sample_rate,  int bits,
                   lqt_codec_info_t * codec_info)
@@ -479,7 +500,11 @@ int lqt_set_video(quicktime_t *file,
   int i;
 
   for(i = 0; i < tracks; i++)
-    lqt_add_video_track(file, frame_w, frame_h, frame_duration, timescale, info);
+    {
+    if(lqt_add_video_track(file, frame_w, frame_h,
+                           frame_duration, timescale, info))
+      return 1;
+    }
   return 0;
   }
 
@@ -500,38 +525,109 @@ int quicktime_set_video(quicktime_t *file,
   return 0;
   }
 
+static int check_image_size(lqt_codec_info_t * info,
+                            int frame_w, int frame_h)
+  {
+  int i;
+  if(info->num_image_sizes)
+    {
+    for(i = 0; i < info->num_image_sizes; i++)
+      {
+      if((frame_w == info->image_sizes[i].width) &&
+         (frame_h == info->image_sizes[i].height))
+        return 1;
+      }
+    
+    return 0;
+    }
+  else
+    return 1;
+  }
+
+int lqt_set_video_codec(quicktime_t *file, int track,
+                        lqt_codec_info_t * info)
+  {
+  quicktime_stsd_t *stsd;
+  
+  if(!check_image_size(info,
+                       quicktime_video_width(file, track),
+                       quicktime_video_height(file, track)))
+    return 1;
+
+  stsd = &file->vtracks[track].track->mdia.minf.stbl.stsd;
+  
+  quicktime_stsd_set_video_codec(stsd, info->fourccs[0]);
+  
+  quicktime_init_video_map(&file->vtracks[track],
+                           file->wr, info);
+  
+  lqt_set_default_video_parameters(file, track);
+  
+  /* Get encoding colormodel */
+  file->vtracks[file->total_vtracks-1].codec->encode_video(file,
+                                                           (uint8_t**)0,
+                                                           track);
+  file->vtracks[track].io_cmodel =
+    file->vtracks[track].stream_cmodel;
+  
+  
+  return 0;
+  }
+
+int lqt_add_video_track_internal(quicktime_t *file,
+                                 int frame_w, int frame_h,
+                                 int frame_duration, int timescale,
+                                 lqt_codec_info_t * info,
+                                 const lqt_compression_info_t * ci)
+  {
+  char * compressor = info ? info->fourccs[0] : NULL;
+  quicktime_trak_t *trak;
+
+  /* Check if the image size is supported */
+  if(info && !check_image_size(info, frame_w, frame_h))
+    {
+    lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN,
+            "Adding video track failed, unsupported image size");
+    return 1;
+    }
+  
+  if(!file->total_vtracks)
+    quicktime_mhvd_init_video(file, &file->moov.mvhd, timescale);
+  file->vtracks = realloc(file->vtracks, (file->total_vtracks+1) *
+                          sizeof(*file->vtracks));
+  memset(&file->vtracks[file->total_vtracks], 0, sizeof(*file->vtracks));
+  
+  if(ci)
+    {
+    lqt_compression_info_copy(&file->vtracks[file->total_vtracks].ci, ci);
+    file->vtracks[file->total_vtracks].stream_cmodel = ci->colormodel;
+    }
+  trak = quicktime_add_track(file);
+  file->vtracks[file->total_vtracks].track = trak;
+  
+  file->total_vtracks++;
+        
+  quicktime_trak_init_video(file, trak, frame_w, frame_h,
+                            frame_duration, timescale, compressor);
+
+
+  if(info)
+    return lqt_set_video_codec(file, file->total_vtracks-1, info);
+  
+  return 0;
+  }
 
 int lqt_add_video_track(quicktime_t *file,
                         int frame_w, int frame_h,
                         int frame_duration, int timescale,
                         lqt_codec_info_t * info)
   {
-  char * compressor = info->fourccs[0];
-  quicktime_trak_t *trak;
-  if(!file->total_vtracks)
-    quicktime_mhvd_init_video(file, &(file->moov.mvhd), timescale);
-  file->vtracks = realloc(file->vtracks, (file->total_vtracks+1) *
-                          sizeof(quicktime_video_map_t));
-  memset(&(file->vtracks[file->total_vtracks]), 0, sizeof(quicktime_video_map_t));
-  trak = quicktime_add_track(file);
-
-  file->total_vtracks++;
-        
-  quicktime_trak_init_video(file, trak, frame_w, frame_h,
-                            frame_duration, timescale, compressor);
-
-  quicktime_init_video_map(&(file->vtracks[file->total_vtracks-1]),
-                           trak, file->wr, info);
-  lqt_set_default_video_parameters(file, file->total_vtracks-1);
-        
-  /* Get encoding colormodel */
-  ((quicktime_codec_t*)(file->vtracks[file->total_vtracks-1].codec))->encode_video(file, (uint8_t**)0, file->total_vtracks-1);
-  file->vtracks[file->total_vtracks-1].io_cmodel =
-    file->vtracks[file->total_vtracks-1].stream_cmodel;
-  return 0;
+  return lqt_add_video_track_internal(file,
+                                      frame_w, frame_h,
+                                      frame_duration, timescale,
+                                      info, NULL);
   }
 
-
 void quicktime_set_framerate(quicktime_t *file, double framerate)
   {
   int i;
@@ -558,7 +654,7 @@ void quicktime_set_framerate(quicktime_t *file, double framerate)
 /* Used for writing only */
 quicktime_trak_t* quicktime_add_track(quicktime_t *file)
   {
-  quicktime_moov_t *moov = &(file->moov);
+  quicktime_moov_t *moov = &file->moov;
   quicktime_trak_t *trak;
   
   //  for(i = moov->total_tracks; i > 0; i--)
@@ -583,7 +679,7 @@ int quicktime_init(quicktime_t *file)
   {
   bzero(file, sizeof(quicktime_t));
   //	quicktime_atom_write_header64(new_file, &file->mdat.atom, "mdat");
-  quicktime_moov_init(&(file->moov));
+  quicktime_moov_init(&file->moov);
   file->max_riff_size = 0x40000000;
   //	file->color_model = BC_RGB888;
   return 0;
@@ -595,19 +691,19 @@ static int quicktime_delete(quicktime_t *file)
   if(file->total_atracks) 
     {
     for(i = 0; i < file->total_atracks; i++)
-      quicktime_delete_audio_map(&(file->atracks[i]));
+      quicktime_delete_audio_map(&file->atracks[i]);
     free(file->atracks);
     }
   if(file->total_vtracks)
     {
     for(i = 0; i < file->total_vtracks; i++)
-      quicktime_delete_video_map(&(file->vtracks[i]));
+      quicktime_delete_video_map(&file->vtracks[i]);
     free(file->vtracks);
     }
   if(file->total_ttracks)
     {
     for(i = 0; i < file->total_ttracks; i++)
-      lqt_delete_text_map(file, &(file->ttracks[i]));
+      lqt_delete_text_map(file, &file->ttracks[i]);
     free(file->ttracks);
     }
   file->total_atracks = 0;
@@ -630,9 +726,9 @@ static int quicktime_delete(quicktime_t *file)
     quicktime_delete_riff(file, file->riff[i]);
     }
 
-  quicktime_moov_delete(&(file->moov));
-  quicktime_mdat_delete(&(file->mdat));
-  quicktime_ftyp_delete(&(file->ftyp));
+  quicktime_moov_delete(&file->moov);
+  quicktime_mdat_delete(&file->mdat);
+  quicktime_ftyp_delete(&file->ftyp);
   return 0;
   }
 
@@ -741,14 +837,14 @@ int quicktime_set_video_position(quicktime_t *file, int64_t frame, int track)
   file->vtracks[track].cur_chunk = chunk;
   
   file->vtracks[track].timestamp =
-    quicktime_sample_to_time(&(trak->mdia.minf.stbl.stts),
+    quicktime_sample_to_time(&trak->mdia.minf.stbl.stts,
                              frame,
-                             &(file->vtracks[track].stts_index),
-                             &(file->vtracks[track].stts_count));
+                             &file->vtracks[track].stts_index,
+                             &file->vtracks[track].stts_count);
 
   /* Resync codec */
 
-  codec = (quicktime_codec_t*)(file->vtracks[track].codec);
+  codec = file->vtracks[track].codec;
   if(codec && codec->resync)
     codec->resync(file, track);
     
@@ -768,10 +864,10 @@ void lqt_seek_video(quicktime_t * file, int track, int64_t time)
   file->vtracks[track].timestamp = time;
   
   frame =
-    quicktime_time_to_sample(&(trak->mdia.minf.stbl.stts),
-                             &(file->vtracks[track].timestamp),
-                             &(file->vtracks[track].stts_index),
-                             &(file->vtracks[track].stts_count));
+    quicktime_time_to_sample(&trak->mdia.minf.stbl.stts,
+                             &file->vtracks[track].timestamp,
+                             &file->vtracks[track].stts_index,
+                             &file->vtracks[track].stts_count);
 
 
   quicktime_set_video_position(file, frame, track);
@@ -804,10 +900,10 @@ int lqt_read_video_frame(quicktime_t * file,
   quicktime_set_position(file, offset);
 
   if(time)
-    *time = quicktime_sample_to_time(&(trak->mdia.minf.stbl.stts),
+    *time = quicktime_sample_to_time(&trak->mdia.minf.stbl.stts,
                                      frame,
-                                     &(file->vtracks[track].stts_index),
-                                     &(file->vtracks[track].stts_count));
+                                     &file->vtracks[track].stts_index,
+                                     &file->vtracks[track].stts_count);
 
   len = quicktime_frame_size(file, frame, track);
   
@@ -942,27 +1038,17 @@ void lqt_set_cmodel(quicktime_t *file, int track, int colormodel)
     {
     file->vtracks[track].io_cmodel = colormodel;
 
-    /* Check if we can encode this colormodel directly */
+    /* Maybe switch the encoding colormodel to better match the IO one. */
     if(file->wr && !file->encoding_started)
       {
-      lqt_codec_info_t ** info;
-      int i;
-      char * name = ((quicktime_codec_t*)(file->vtracks[track].codec))->codec_name;
+      lqt_codec_info_t * info = file->vtracks[track].codec->info;
+      int encoding_cmodel = lqt_get_best_target_colormodel(
+              colormodel, info->encoding_colormodels);
       
-      info = lqt_find_video_codec_by_name(name);
-
-      if((*info)->encoding_colormodels)
+      if (encoding_cmodel != LQT_COLORMODEL_NONE)
         {
-        for(i = 0; i < (*info)->num_encoding_colormodels; i++)
-          {
-          if((*info)->encoding_colormodels[i] == colormodel)
-            {
-            file->vtracks[track].stream_cmodel = colormodel;
-            break;
-            }
-          }
+        file->vtracks[track].stream_cmodel = encoding_cmodel;
         }
-      lqt_destroy_codec_info(info);
       }
     }
   else
@@ -1049,7 +1135,7 @@ int64_t lqt_video_duration(quicktime_t * file, int track)
   int64_t dummy1;
   int64_t dummy2;
   return
-    quicktime_sample_to_time(&(file->vtracks[track].track->mdia.minf.stbl.stts), -1,
+    quicktime_sample_to_time(&file->vtracks[track].track->mdia.minf.stbl.stts, -1,
                              &dummy1, &dummy2);
   }
 
@@ -1107,20 +1193,17 @@ int quicktime_write_audio(quicktime_t *file,
   {
   int result;
   int64_t bytes;
-  quicktime_atom_t chunk_atom;
   quicktime_audio_map_t *track_map = &file->atracks[track];
   quicktime_trak_t *trak = track_map->track;
                                                                                                                   
   /* write chunk for 1 track */
   bytes = samples * quicktime_audio_bits(file, track) / 8 * file->atracks[track].channels;
-  quicktime_write_chunk_header(file, trak, &chunk_atom);
+  quicktime_write_chunk_header(file, trak);
   result = !quicktime_write_data(file, audio_buffer, bytes);
-  quicktime_write_chunk_footer(file,
-                               trak,
-                               track_map->cur_chunk,
-                               &chunk_atom,
-                               samples);
-                                                                                                                  
+
+  trak->chunk_samples = samples;
+  quicktime_write_chunk_footer(file, trak);
+  
   /*      file->atracks[track].current_position += samples; */
   file->atracks[track].cur_chunk++;
   return result;
@@ -1291,12 +1374,29 @@ int quicktime_has_keyframes(quicktime_t *file, int track)
   return stss->total_entries > 0;
   }
 
+int lqt_is_keyframe(quicktime_t *file, int track, int frame)
+  {
+  int i;
+  quicktime_stss_t *stss = &file->vtracks[track].track->mdia.minf.stbl.stss;
+
+  if(!stss->total_entries)
+    return 1;
+
+  frame++;
+  
+  for(i = 0; i < stss->total_entries; i++)
+    {
+    if(stss->table[i].sample == frame)
+      return 1;
+    }
+  return 0;
+  }
+
+
 int quicktime_init_video_map(quicktime_video_map_t *vtrack,
-                             quicktime_trak_t *trak,
                              int encode,
                              lqt_codec_info_t * info)
   {
-  vtrack->track = trak;
   vtrack->current_position = 0;
   vtrack->cur_chunk = 0;
   vtrack->io_cmodel = BC_RGB888;
@@ -1306,7 +1406,7 @@ int quicktime_init_video_map(quicktime_video_map_t *vtrack,
 
 int quicktime_delete_video_map(quicktime_video_map_t *vtrack)
   {
-  quicktime_delete_vcodec(vtrack);
+  quicktime_delete_codec(vtrack->codec);
   if(vtrack->temp_frame)
     lqt_rows_free(vtrack->temp_frame);
   if(vtrack->timecodes)
@@ -1315,29 +1415,28 @@ int quicktime_delete_video_map(quicktime_video_map_t *vtrack)
     free(vtrack->timestamps);
   if(vtrack->picture_numbers)
     free(vtrack->picture_numbers);
-        
-        
+  
+  lqt_compression_info_free(&vtrack->ci);
         
   return 0;
   }
 
 int quicktime_init_audio_map(quicktime_t * file,
                              quicktime_audio_map_t *atrack,
-                             quicktime_trak_t *trak, int encode,
+                             int encode,
                              lqt_codec_info_t * info)
   {
   if(!encode)
-    atrack->total_samples = quicktime_track_samples(file, trak);
-  atrack->track = trak;
-  atrack->channels = trak->mdia.minf.stbl.stsd.table[0].channels;
-  atrack->samplerate = (int)(trak->mdia.minf.stbl.stsd.table[0].samplerate + 0.5);
+    atrack->total_samples = quicktime_track_samples(file, atrack->track);
+  atrack->channels = atrack->track->mdia.minf.stbl.stsd.table[0].channels;
+  atrack->samplerate = (int)(atrack->track->mdia.minf.stbl.stsd.table[0].samplerate + 0.5);
   atrack->current_position = 0;
   atrack->cur_chunk = 0;
 
   if(!encode) 
     {
     /* Set channel setup */
-    if(trak->mdia.minf.stbl.stsd.table[0].has_chan)
+    if(atrack->track->mdia.minf.stbl.stsd.table[0].has_chan)
       quicktime_get_chan(atrack);
     }
   quicktime_init_acodec(atrack, encode, info);
@@ -1346,11 +1445,12 @@ int quicktime_init_audio_map(quicktime_t * file,
 
 int quicktime_delete_audio_map(quicktime_audio_map_t *atrack)
   {
-  quicktime_delete_acodec(atrack);
+  quicktime_delete_codec(atrack->codec);
   if(atrack->sample_buffer)
     free(atrack->sample_buffer);
   if(atrack->channel_setup)
     free(atrack->channel_setup);
+  lqt_compression_info_free(&atrack->ci);
   return 0;
   }
 
@@ -1369,11 +1469,12 @@ void quicktime_init_maps(quicktime_t * file)
       {
       while(!file->moov.trak[track]->mdia.minf.is_audio)
         track++;
-      quicktime_init_audio_map(file, &(file->atracks[i]), file->moov.trak[track],
+      file->atracks[i].track = file->moov.trak[track];
+      quicktime_init_audio_map(file, &file->atracks[i],
                                file->wr,
                                (lqt_codec_info_t*)0);
       /* Some codecs set the channel setup */
-      ((quicktime_codec_t*)file->atracks[i].codec)->decode_audio(file, (void*)0, 0, i);
+      file->atracks[i].codec->decode_audio(file, (void*)0, 0, i);
       }
     }
 
@@ -1387,18 +1488,19 @@ void quicktime_init_maps(quicktime_t * file)
       {
       while(!file->moov.trak[track]->mdia.minf.is_video)
         track++;
-      
-      quicktime_init_video_map(&(file->vtracks[i]), file->moov.trak[track],
+
+      file->vtracks[i].track = file->moov.trak[track];
+      quicktime_init_video_map(&file->vtracks[i],
                                file->wr,
                                (lqt_codec_info_t*)0);
       /* Get decoder colormodel */
-      ((quicktime_codec_t*)file->vtracks[i].codec)->decode_video(file, (uint8_t**)0, i);
+      file->vtracks[i].codec->decode_video(file, (uint8_t**)0, i);
       file->vtracks[i].io_cmodel = file->vtracks[i].stream_cmodel;
       
       lqt_get_default_rowspan(file->vtracks[i].stream_cmodel,
                               quicktime_video_width(file, i),
-                              &(file->vtracks[i].stream_row_span),
-                              &(file->vtracks[i].stream_row_span_uv));
+                              &file->vtracks[i].stream_row_span,
+                              &file->vtracks[i].stream_row_span_uv);
 
       /* Get interlace mode */
       if((file->vtracks[i].interlace_mode == LQT_INTERLACE_NONE) &&
@@ -1532,7 +1634,7 @@ int quicktime_read_info(quicktime_t *file)
           {
           if(quicktime_atom_is(&leaf_atom, "mdat"))
             {
-            quicktime_read_mdat(file, &(file->mdat), &leaf_atom);
+            quicktime_read_mdat(file, &file->mdat, &leaf_atom);
             }
           else
             if(quicktime_atom_is(&leaf_atom, "ftyp"))
@@ -1554,7 +1656,7 @@ int quicktime_read_info(quicktime_t *file)
                 quicktime_set_position(file, start_position);
                 free(temp);
 
-                quicktime_read_moov(file, &(file->moov), &leaf_atom);
+                quicktime_read_moov(file, &file->moov, &leaf_atom);
                 got_header = 1;
                 }
               else
@@ -1645,16 +1747,18 @@ int quicktime_read_info(quicktime_t *file)
       /* go back to the original position */
       quicktime_set_position(file, start_position);
       }
-        
+
+  /* Set file type if no ftyp is there (must be done before initializing the codecs) */
+  if(file->file_type == LQT_FILE_NONE)
+    file->file_type = LQT_FILE_QT_OLD;
+
+  
   /* Initialize track map objects */
   if(got_header)
     {
     quicktime_init_maps(file);
     }
 
-  /* Set file type if no ftyp is there */
-  if(file->file_type == LQT_FILE_NONE)
-    file->file_type = LQT_FILE_QT_OLD;
         
   /* Shut down preload in case of an obsurdly high temp_size */
   quicktime_set_preload(file, 0);
@@ -1665,23 +1769,23 @@ int quicktime_dump(quicktime_t *file)
   {
   lqt_dump("quicktime_dump\n");
   if(file->has_ftyp)
-    quicktime_ftyp_dump(&(file->ftyp));
+    quicktime_ftyp_dump(&file->ftyp);
 	
   lqt_dump("movie data (mdat)\n");
   lqt_dump(" size %"PRId64"\n", file->mdat.atom.size);
   lqt_dump(" start %"PRId64"\n", file->mdat.atom.start);
-  quicktime_moov_dump(&(file->moov));
+  quicktime_moov_dump(&file->moov);
   if (lqt_qtvr_get_object_track(file) >= 0)
     {
-    quicktime_obji_dump(&(file->qtvr_node[0].obji));
+    quicktime_obji_dump(&file->qtvr_node[0].obji);
     }
   if (lqt_qtvr_get_panorama_track(file) >= 0)
     {
-    quicktime_pdat_dump(&(file->qtvr_node[0].pdat));
+    quicktime_pdat_dump(&file->qtvr_node[0].pdat);
     }
   if (lqt_qtvr_get_qtvr_track(file) >= 0)
     {
-    quicktime_ndhd_dump(&(file->qtvr_node[0].ndhd));
+    quicktime_ndhd_dump(&file->qtvr_node[0].ndhd);
     }
   if(file->file_type & (LQT_FILE_AVI | LQT_FILE_AVI_ODML))
     {
@@ -1800,7 +1904,7 @@ static quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_
     if(wr)
       {
       if(new_file->has_ftyp)
-        quicktime_write_ftyp(new_file, &(new_file->ftyp));
+        quicktime_write_ftyp(new_file, &new_file->ftyp);
       quicktime_atom_write_header64(new_file, 
                                     &new_file->mdat.atom, 
                                     "mdat");
@@ -1868,6 +1972,10 @@ int quicktime_close(quicktime_t *file)
   int result = 0;
   if(file->wr)
     {
+    /* Finish final chunk if necessary */
+    if(file->write_trak)
+      quicktime_write_chunk_footer(file, file->write_trak);
+    
     quicktime_codecs_flush(file);
 
     for(i = 0; i < file->total_vtracks; i++)
@@ -1919,8 +2027,8 @@ int quicktime_close(quicktime_t *file)
         }
       // Atoms are only written here
       quicktime_atom_write_footer(file, &file->mdat.atom);
-      quicktime_finalize_moov(file, &(file->moov));
-      quicktime_write_moov(file, &(file->moov));
+      quicktime_finalize_moov(file, &file->moov);
+      quicktime_write_moov(file, &file->moov);
       }
     }
   quicktime_file_close(file);
@@ -1938,13 +2046,16 @@ int quicktime_close(quicktime_t *file)
 static void apply_default_parameters(quicktime_t * file,
                                      int track,
                                      quicktime_codec_t * codec,
-                                     lqt_codec_info_t * codec_info,
                                      int encode)
   {
   int num_parameters;
   lqt_parameter_info_t * parameter_info;
   int j;
+  
+  lqt_codec_info_t * codec_info = codec->info;
 
+  if(!codec_info)
+    return;
   
   if(encode)
     {
@@ -1966,14 +2077,14 @@ static void apply_default_parameters(quicktime_t * file,
                 parameter_info[j].name,
                 parameter_info[j].val_default.val_int);
         codec->set_parameter(file, track, parameter_info[j].name,
-                             &(parameter_info[j].val_default.val_int));
+                             &parameter_info[j].val_default.val_int);
         break;
       case LQT_PARAMETER_FLOAT:
         lqt_log(file, LQT_LOG_DEBUG, LOG_DOMAIN, "Setting parameter %s to %f",
                 parameter_info[j].name,
                 parameter_info[j].val_default.val_float);
         codec->set_parameter(file, track, parameter_info[j].name,
-                             &(parameter_info[j].val_default.val_float));
+                             &parameter_info[j].val_default.val_float);
         break;
       case LQT_PARAMETER_STRING:
       case LQT_PARAMETER_STRINGLIST:
@@ -1992,15 +2103,12 @@ static void apply_default_parameters(quicktime_t * file,
 
 void lqt_set_default_video_parameters(quicktime_t * file, int track)
   {
-  lqt_codec_info_t ** codec_info;
-  quicktime_codec_t * codec;
-    
-  codec = (quicktime_codec_t*)(file->vtracks[track].codec);
-  codec_info = lqt_find_video_codec_by_name(codec->codec_name);
-  if(codec_info)
+  int i;
+
+  for(i = 0; i < file->total_vtracks; i++)
     {
-    apply_default_parameters(file, track, codec, *codec_info, file->wr);
-    lqt_destroy_codec_info(codec_info);
+    apply_default_parameters(file, track, file->vtracks[track].codec,
+                             file->wr);
     }
   }
 
@@ -2009,17 +2117,10 @@ void lqt_set_default_video_parameters(quicktime_t * file, int track)
 void lqt_set_default_audio_parameters(quicktime_t * file, int track)
   {
   int i;
-  lqt_codec_info_t ** codec_info;
-  quicktime_codec_t * codec;
   for(i = 0; i < file->total_atracks; i++)
     {
-    codec = (quicktime_codec_t*)(file->atracks[i].codec);
-    codec_info = lqt_find_audio_codec_by_name(codec->codec_name);
-    if(codec_info)
-      {
-      apply_default_parameters(file, i, codec, *codec_info, file->wr);
-      lqt_destroy_codec_info(codec_info);
-      }
+    apply_default_parameters(file, i, file->atracks[track].codec,
+                             file->wr);
     }
   }
 
@@ -2332,20 +2433,18 @@ lqt_sample_format_t lqt_get_sample_format(quicktime_t * file, int track)
   if(track < 0 || track > file->total_atracks)
     return LQT_SAMPLE_UNDEFINED;
 
-  atrack = &(file->atracks[track]);
+  atrack = &file->atracks[track];
 
   if(atrack->sample_format == LQT_SAMPLE_UNDEFINED)
     {
     if(file->wr)
       {
-      ((quicktime_codec_t*)(atrack->codec))->encode_audio(file, (void*)0, 
-                                                          0, track);
+      atrack->codec->encode_audio(file, (void*)0, 0, track);
       
       }
     else
       {
-      ((quicktime_codec_t*)(atrack->codec))->decode_audio(file, (void*)0, 
-                                                          0, track);
+      atrack->codec->decode_audio(file, (void*)0, 0, track);
 
       }
     }
@@ -2359,40 +2458,90 @@ void lqt_init_vbr_audio(quicktime_t * file, int track)
   trak->mdia.minf.stbl.stsd.table[0].compression_id = -2;
   trak->mdia.minf.stbl.stsz.sample_size = 0;
   trak->mdia.minf.is_audio_vbr = 1;
+
+  if(trak->strl)
+    {
+    trak->strl->strh.dwRate = quicktime_sample_rate(file, track);
+    trak->strl->strh.dwScale = 0;
+    trak->strl->strh.dwSampleSize = 0;
+    
+    trak->strl->strf.wf.f.WAVEFORMAT.nBlockAlign = 0;
+    trak->strl->strf.wf.f.WAVEFORMAT.nAvgBytesPerSec =  18120; // Probably doesn't matter
+    trak->strl->strf.wf.f.PCMWAVEFORMAT.wBitsPerSample = 0;
+    }
   }
 
-void lqt_start_audio_vbr_chunk(quicktime_t * file, int track)
+LQT_EXTERN void lqt_set_audio_bitrate(quicktime_t * file, int track, int bitrate)
   {
-  file->atracks[track].vbr_num_frames = 0;
+  quicktime_trak_t * trak = file->atracks[track].track;
+
+  if(!trak->strl)
+    return;
+  
+  /* strh stuff */
+  trak->strl->strh.dwRate = bitrate / 8;
+  trak->strl->strh.dwScale = 1;
+  trak->strl->strh.dwSampleSize = 1;
+  /* WAVEFORMATEX stuff */
+  
+  trak->strl->strf.wf.f.WAVEFORMAT.nBlockAlign = 1;
+  trak->strl->strf.wf.f.WAVEFORMAT.nAvgBytesPerSec =  bitrate / 8;
+  trak->strl->strf.wf.f.PCMWAVEFORMAT.wBitsPerSample = 0;
   }
 
+
 void lqt_start_audio_vbr_frame(quicktime_t * file, int track)
   {
   quicktime_audio_map_t * atrack = &file->atracks[track];
+  
+  /* Make chunk at maximum 10 VBR packets large */
+  if((file->write_trak == atrack->track) &&
+     (atrack->track->chunk_samples >= 10))
+    {
+    quicktime_write_chunk_footer(file, file->write_trak);
+    quicktime_write_chunk_header(file, atrack->track);
+    }
   atrack->vbr_frame_start = quicktime_position(file);
+  
   }
 
 void lqt_finish_audio_vbr_frame(quicktime_t * file, int track, int num_samples)
   {
+  int size;
   quicktime_stsz_t * stsz;
   quicktime_stts_t * stts;
+  long vbr_frames_written;
   quicktime_audio_map_t * atrack = &file->atracks[track];
   
-  stsz = &(file->atracks[track].track->mdia.minf.stbl.stsz);
-  stts = &(file->atracks[track].track->mdia.minf.stbl.stts);
+  stsz = &atrack->track->mdia.minf.stbl.stsz;
+  stts = &atrack->track->mdia.minf.stbl.stts;
+
+  vbr_frames_written = stsz->total_entries;
   
   /* Update stsz */
 
-  quicktime_update_stsz(stsz, file->atracks[track].vbr_frames_written, 
-                        quicktime_position(file) - file->atracks[track].vbr_frame_start);
+  size = quicktime_position(file) - atrack->vbr_frame_start;
+  
+  quicktime_update_stsz(stsz, vbr_frames_written, size);
+  
+  if(atrack->track->strl)
+    {
+    quicktime_strl_t * strl = atrack->track->strl;
+    
+    if(size > strl->strf.wf.f.WAVEFORMAT.nBlockAlign)
+      strl->strf.wf.f.WAVEFORMAT.nBlockAlign = size;
+
+    if(!strl->strh.dwScale)
+      strl->strh.dwScale = num_samples;
+
+    strl->strh.dwLength++;
+    }
+  
   /* Update stts */
   
-  quicktime_update_stts(stts, file->atracks[track].vbr_frames_written, num_samples);
-
-  atrack->vbr_num_frames++;
-  atrack->vbr_frames_written++;
-
+  quicktime_update_stts(stts, vbr_frames_written, num_samples);
   
+  atrack->track->chunk_samples++;
   }
 
 /* VBR Reading support */
@@ -2404,6 +2553,8 @@ int lqt_audio_is_vbr(quicktime_t * file, int track)
   return file->atracks[track].track->mdia.minf.is_audio_vbr;
   }
 
+
+
 /* Get the index of the VBR packet (== sample) containing a specified
    uncompressed sample */
 
@@ -2497,7 +2648,8 @@ int lqt_chunk_of_sample_vbr(int64_t *chunk_sample,
 
 /* Determine the number of VBR packets (=samples) in one chunk */
 
-int lqt_audio_num_vbr_packets(quicktime_t * file, int track, long chunk, int * samples)
+int lqt_audio_num_vbr_packets(quicktime_t * file,
+                              int track, long chunk, int * samples)
   {
   int64_t start_sample;
   
@@ -2509,7 +2661,7 @@ int lqt_audio_num_vbr_packets(quicktime_t * file, int track, long chunk, int * s
   
   trak = file->atracks[track].track;
     
-  stsc = &(trak->mdia.minf.stbl.stsc);
+  stsc = &trak->mdia.minf.stbl.stsc;
 
   if(chunk >= trak->mdia.minf.stbl.stco.total_entries)
     return 0;
@@ -2536,7 +2688,7 @@ int lqt_audio_num_vbr_packets(quicktime_t * file, int track, long chunk, int * s
         (stsc->table[i+1].chunk - stsc->table[i].chunk) * stsc->table[i].samples;
     }
   if(samples)
-    *samples = get_uncompressed_samples(&(trak->mdia.minf.stbl.stts),
+    *samples = get_uncompressed_samples(&trak->mdia.minf.stbl.stts,
                                         start_sample, start_sample + result);
   
   return result;
@@ -2554,7 +2706,7 @@ int lqt_audio_read_vbr_packet(quicktime_t * file, int track, long chunk, int pac
   long first_chunk_packet; /* Index of first packet in the chunk */
   
   trak = file->atracks[track].track;
-  stsc = &(trak->mdia.minf.stbl.stsc);
+  stsc = &trak->mdia.minf.stbl.stsc;
 
   if(chunk >= trak->mdia.minf.stbl.stco.total_entries)
     return 0;
